@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: GenPackage.java,v 1.17 2005/06/22 19:55:04 davidms Exp $
+ * $Id: GenPackage.java,v 1.27 2006/05/04 14:30:45 emerks Exp $
  */
 package org.eclipse.emf.codegen.ecore.genmodel;
 
@@ -39,12 +39,16 @@ import org.eclipse.emf.ecore.EPackage;
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isAdapterFactory <em>Adapter Factory</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isLoadInitialization <em>Load Initialization</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getInterfacePackageSuffix <em>Interface Package Suffix</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getMetaDataPackageSuffix <em>Meta Data Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getClassPackageSuffix <em>Class Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getUtilityPackageSuffix <em>Utility Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getProviderPackageSuffix <em>Provider Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getPresentationPackageSuffix <em>Presentation Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getTestsPackageSuffix <em>Tests Package Suffix</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isGenerateExampleClass <em>Generate Example Class</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isLiteralsInterface <em>Literals Interface</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isDataTypeConverters <em>Data Type Converters</em>}</li>
+ *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isMultipleEditorPages <em>Multiple Editor Pages</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getEcorePackage <em>Ecore Package</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getGenModel <em>Gen Model</em>}</li>
  *   <li>{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getGenEnums <em>Gen Enums</em>}</li>
@@ -59,7 +63,8 @@ import org.eclipse.emf.ecore.EPackage;
  * @model
  * @generated
  */
-public interface GenPackage extends GenBase{
+public interface GenPackage extends GenBase
+{
   /**
    * Returns the value of the '<em><b>Prefix</b></em>' attribute.
    * <!-- begin-user-doc -->
@@ -247,6 +252,33 @@ public interface GenPackage extends GenBase{
    */
   void setInterfacePackageSuffix(String value);
 
+  /**
+   * Returns the value of the '<em><b>Meta Data Package Suffix</b></em>' attribute.
+   * The default value is <code>""</code>.
+   * <!-- begin-user-doc -->
+   * <p>
+   * If the meaning of the '<em>Meta Data Package Suffix</em>' attribute isn't clear,
+   * there really should be more of a description here...
+   * </p>
+   * <!-- end-user-doc -->
+   * @return the value of the '<em>Meta Data Package Suffix</em>' attribute.
+   * @see #setMetaDataPackageSuffix(String)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_MetaDataPackageSuffix()
+   * @model default=""
+   * @generated
+   */
+  String getMetaDataPackageSuffix();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#getMetaDataPackageSuffix <em>Meta Data Package Suffix</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Meta Data Package Suffix</em>' attribute.
+   * @see #getMetaDataPackageSuffix()
+   * @generated
+   */
+  void setMetaDataPackageSuffix(String value);
+
   /**
    * Returns the value of the '<em><b>Class Package Suffix</b></em>' attribute.
    * The default value is <code>"impl"</code>.
@@ -409,6 +441,86 @@ public interface GenPackage extends GenBase{
    */
   void setGenerateExampleClass(boolean value);
 
+  /**
+   * Returns the value of the '<em><b>Literals Interface</b></em>' attribute.
+   * The default value is <code>"true"</code>.
+   * <!-- begin-user-doc -->
+   * <p>
+   * If the meaning of the '<em>Literals Interface</em>' attribute isn't clear,
+   * there really should be more of a description here...
+   * </p>
+   * <!-- end-user-doc -->
+   * @return the value of the '<em>Literals Interface</em>' attribute.
+   * @see #setLiteralsInterface(boolean)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_LiteralsInterface()
+   * @model default="true"
+   * @generated
+   */
+  boolean isLiteralsInterface();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isLiteralsInterface <em>Literals Interface</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Literals Interface</em>' attribute.
+   * @see #isLiteralsInterface()
+   * @generated
+   */
+  void setLiteralsInterface(boolean value);
+
+  /**
+   * Returns the value of the '<em><b>Data Type Converters</b></em>' attribute.
+   * <!-- begin-user-doc -->
+   * <p>
+   * If the meaning of the '<em>Data Type Converters</em>' attribute isn't clear,
+   * there really should be more of a description here...
+   * </p>
+   * <!-- end-user-doc -->
+   * @return the value of the '<em>Data Type Converters</em>' attribute.
+   * @see #setDataTypeConverters(boolean)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_DataTypeConverters()
+   * @model
+   * @generated
+   */
+  boolean isDataTypeConverters();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isDataTypeConverters <em>Data Type Converters</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Data Type Converters</em>' attribute.
+   * @see #isDataTypeConverters()
+   * @generated
+   */
+  void setDataTypeConverters(boolean value);
+
+  /**
+   * Returns the value of the '<em><b>Multiple Editor Pages</b></em>' attribute.
+   * The default value is <code>"true"</code>.
+   * <!-- begin-user-doc -->
+   * <p>
+   * If the meaning of the '<em>Multiple Editor Pages</em>' attribute isn't clear,
+   * there really should be more of a description here...
+   * </p>
+   * <!-- end-user-doc -->
+   * @return the value of the '<em>Multiple Editor Pages</em>' attribute.
+   * @see #setMultipleEditorPages(boolean)
+   * @see org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage#getGenPackage_MultipleEditorPages()
+   * @model default="true"
+   * @generated
+   */
+  boolean isMultipleEditorPages();
+
+  /**
+   * Sets the value of the '{@link org.eclipse.emf.codegen.ecore.genmodel.GenPackage#isMultipleEditorPages <em>Multiple Editor Pages</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param value the new value of the '<em>Multiple Editor Pages</em>' attribute.
+   * @see #isMultipleEditorPages()
+   * @generated
+   */
+  void setMultipleEditorPages(boolean value);
+
   /**
    * Returns the value of the '<em><b>Ecore Package</b></em>' reference.
    * <!-- begin-user-doc -->
@@ -546,6 +658,8 @@ public interface GenPackage extends GenBase{
   EList getGenClassifiers();
 
   String getInterfacePackageName();
+  String getReflectionPackageName();
+  String getReflectionClassPackageName();
   String getClassPackageName();
   String getUtilitiesPackageName();
   String getTestsPackageName();
@@ -571,6 +685,10 @@ public interface GenPackage extends GenBase{
   String getFactoryClassName();
   String getQualifiedFactoryClassName();
   String getImportedFactoryClassName();
+  String getFactoryInstanceName();
+  String getQualifiedFactoryInstanceAccessor();
+  String getQualifiedEFactoryInstanceAccessor();
+  String getQualifiedEFactoryInternalInstanceAccessor();
 
   String getAdapterFactoryClassName();
   String getQualifiedAdapterFactoryClassName();
@@ -578,12 +696,20 @@ public interface GenPackage extends GenBase{
   String getUncapAdapterFactoryClassName();
 
   String getSwitchClassName();
+  String getQualifiedSwitchClassName();
   String getValidatorClassName();
+  String getQualifiedValidatorClassName();
   String getImportedValidatorClassName();
+
   String getTestSuiteClassName();
-  String getExampleClassName();
   String getQualifiedTestSuiteClassName();
   String getImportedTestSuiteClassName();
+  String getExampleClassName();
+  String getQualifiedExampleClassName();
+
+  String getQualifiedXMLProcessorClassName();
+  String getXMLProcessorClassName();
+  String getImportedXMLProcessorBaseClassName();
 
   List getAllGenDataTypes();
 
@@ -650,12 +776,14 @@ public interface GenPackage extends GenBase{
 
   void initialize(EPackage ePackage);
 
+  void prepareCache();
+  void clearCache();
+
   /**
-   * @deprecated Use {@link GenBase#generateSchema(IProgressMonitor)} instead.  This
-   * method will be removed soon.
+   * @deprecated In EMF 2.2, schema generation is properly done via a model exporter. This method will be removed after 2.2.
    */
   void generateSchema();
-  
+
   //
   // EMFEdit generation
   //
@@ -687,6 +815,9 @@ public interface GenPackage extends GenBase{
   String getQualifiedEditorPluginClassName();
   String getImportedEditorPluginClassName();
 
+  String getModelIconFileName();
+  String getModelWizardIconFileName();
+
   // String getCapPackageID();
   List/*GenFeature*/ getAllGenFeatures(); // Includes features in other packages that delegate to those in this one.
 
@@ -703,6 +834,7 @@ public interface GenPackage extends GenBase{
   String getAnnotationSourceIdentifier(String annotationSource);
   List getAllAnnotations();
   String getAnnotatedModelElementAccessor(EAnnotation eAnnotation);
+  List getAllNestedAnnotations(EAnnotation eAnnotation);
 
   String getResourceClassName();
   String getQualifiedResourceClassName();
@@ -716,6 +848,7 @@ public interface GenPackage extends GenBase{
 
   boolean hasXMLMap();
   boolean hasDocumentRoot();
+  GenClass getDocumentRoot();
   boolean hasExtendedMetaData();
   boolean hasTargetNamespace();
 
