@@ -54,7 +54,7 @@ public class PluginXML
 
   public String generate(Object argument)
   {
-    StringBuffer stringBuffer = new StringBuffer();
+    final StringBuffer stringBuffer = new StringBuffer();
     
 /**
  * <copyright>
@@ -108,6 +108,7 @@ public class PluginXML
     stringBuffer.append(TEXT_19);
     }
      for (Iterator i = genModel.getAllGenPackagesWithClassifiers().iterator(); i.hasNext(); ) { GenPackage genPackage = (GenPackage)i.next(); 
+    if (!genPackage.getGenClasses().isEmpty()) {
     stringBuffer.append(TEXT_20);
     stringBuffer.append(genPackage.getNSURI());
     stringBuffer.append(TEXT_21);
@@ -119,6 +120,7 @@ public class PluginXML
     }
     stringBuffer.append(TEXT_24);
     }
+    }
     if (genModel.sameModelEditProject()) {
      for (Iterator i = genModel.getAllGenPackagesWithClassifiers().iterator(); i.hasNext(); ) { GenPackage genPackage = (GenPackage)i.next(); 
     stringBuffer.append(TEXT_25);
