@@ -23,7 +23,7 @@ public class PluginProperties
 
   public String generate(Object argument)
   {
-    StringBuffer stringBuffer = new StringBuffer();
+    final StringBuffer stringBuffer = new StringBuffer();
     
 /**
  * <copyright>
