@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2004 IBM Corporation and others.
+ * Copyright (c) 2004-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,19 +12,16 @@
  *
  * </copyright>
  *
- * $Id: BasicDiagnostic.java,v 1.3 2005/06/08 06:19:08 nickb Exp $
+ * $Id: BasicDiagnostic.java,v 1.10 2006/05/01 21:09:48 davidms Exp $
  */
 package org.eclipse.emf.common.util;
 
-
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.runtime.IStatus;
 
-import org.eclipse.emf.common.util.BasicEList;
-
 
 /**
  * A basic implementation of a diagostic that that also acts as a chain.
@@ -66,6 +63,13 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
    * @see #getCode
    */
   protected int code;
+  
+  /**
+   * Default Constructor (no initialization for local parameters)
+   */
+  public BasicDiagnostic()
+  {
+  }
 
   public BasicDiagnostic(String source, int code, String message, Object[] data) 
   {
@@ -106,6 +110,11 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
       return new BasicEList.UnmodifiableEList(copy.length, copy);
     }
   }
+  
+  protected void setSeverity(int severity)
+  {
+    this.severity = severity;
+  }
 
   public int getSeverity()
   {
@@ -130,10 +139,20 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
         Collections.unmodifiableList(children);
   }
 
+  protected void setSource(String source)
+  {
+    this.source = source;
+  }
+
   public String getSource()
   {
     return source;
   }
+  
+  protected void setCode(int code)
+  {
+    this.code = code;
+  }
 
   public int getCode()
   {
@@ -193,11 +212,33 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
 
     return severity;
   }
+  
+  /**
+   * Returns the first throwable object available in the {@link #data} list, 
+   * which is set when this diagnostic is instantiated.
+   */
+  public Throwable getException()
+  {
+    List data = getData();
+    if (data != null)
+    {
+      for (Iterator i = data.iterator(); i.hasNext(); )
+      {
+        Object d = i.next();
+        if (d instanceof Throwable)
+        {
+          return (Throwable)d;
+        }
+      }
+    }
+    return null;
+  }
 
   private static class Wrapper implements IStatus
   {
     protected static final IStatus [] EMPTY_CHILDREN = new IStatus [0];
 
+    protected Throwable throwable;
     protected Diagnostic diagnostic;
     protected IStatus [] wrappedChildren;
 
@@ -205,6 +246,12 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
     {
       this.diagnostic = diagnostic;
     }
+    
+    public Wrapper(DiagnosticException diagnosticException)
+    {
+      throwable = diagnosticException;
+      diagnostic = diagnosticException.getDiagnostic();
+    }
 
     public IStatus[] getChildren()
     {
@@ -234,15 +281,7 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
     
     public Throwable getException()
     {
-      for (Iterator i = diagnostic.getData().iterator(); i.hasNext(); )
-      {
-        Object data = i.next();
-        if (data instanceof Throwable)
-        {
-          return (Throwable)data;
-        }
-      }
-      return null;
+      return throwable != null ? throwable : diagnostic.getException();
     }
     
     public String getMessage()
@@ -284,15 +323,73 @@ public class BasicDiagnostic implements Diagnostic, DiagnosticChain
     {
       return new Wrapper(diagnostic);
     }
+    
+    public static IStatus create(DiagnosticException diagnosticException)
+    {
+      return new Wrapper(diagnosticException);
+    }
   }
 
   /**
-   * Return the diagnostic viewed as an {@link IStatus}.
+   * Returns the diagnostic viewed as an {@link IStatus}.
    */
   public static IStatus toIStatus(Diagnostic diagnostic)
   {
     return Wrapper.create(diagnostic);
   }
+  
+  /**
+   * Returns the diagnostic exception viewed as an {@link IStatus}.
+   */
+  public static IStatus toIStatus(DiagnosticException diagnosticException)
+  {
+    return Wrapper.create(diagnosticException);
+  }
+  
+  /**
+   * Returns the throwable viewed as a {@link Diagnostic}.
+   * 
+   * @param throwable
+   * @return {@link Diagnostic}
+   */
+  public static Diagnostic toDiagnostic(Throwable throwable)
+  {
+    if (throwable instanceof DiagnosticException)
+    {
+      return ((DiagnosticException)throwable).getDiagnostic();
+    }
+    else if (throwable instanceof WrappedException)
+    {
+      return toDiagnostic(throwable.getCause());
+    }
+    
+    String message = throwable.getClass().getName();
+    int index = message.lastIndexOf('.');
+    if (index >= 0)
+    {
+      message = message.substring(index + 1);
+    }
+    if (throwable.getLocalizedMessage() != null)
+    {
+      message = message + ": " + throwable.getLocalizedMessage();
+    }
+    
+    BasicDiagnostic basicDiagnostic = 
+      new BasicDiagnostic
+        (Diagnostic.ERROR,
+         "org.eclipse.emf.common", 
+         0, 
+         message,
+         new Object[] { throwable });
+    
+    while (throwable.getCause() != null && throwable.getCause() != throwable)
+    {
+      throwable = throwable.getCause();
+      basicDiagnostic.add(toDiagnostic(throwable));
+    }
+    
+    return basicDiagnostic;
+  }  
 
   public String toString()
   {
