@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EClassImpl.java,v 1.17 2005/06/08 06:20:10 nickb Exp $
+ * $Id: EClassImpl.java,v 1.27 2006/08/21 15:28:16 emerks Exp $
  */
 
 package org.eclipse.emf.ecore.impl;
@@ -33,7 +33,6 @@ import org.eclipse.emf.ecore.EClass;
 import org.eclipse.emf.ecore.EClassifier;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.EOperation;
-import org.eclipse.emf.ecore.EPackage;
 import org.eclipse.emf.ecore.EReference;
 import org.eclipse.emf.ecore.EStructuralFeature;
 import org.eclipse.emf.ecore.EcorePackage;
@@ -105,7 +104,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
     super();
   }
 
-  public void freeze()
+  protected void freeze()
   {
     getEAllAttributes();
     getEAllReferences();
@@ -116,6 +115,20 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
 
     getESuperAdapter().getSubclasses().clear();
     
+    if (eStructuralFeatures != null)
+    {
+      for (int i = 0, size = eStructuralFeatures.size(); i < size; ++i)
+      {
+        freeze(eStructuralFeatures.get(i));
+      }
+    }
+    if (eOperations != null)
+    {
+      for (int i = 0, size = eOperations.size(); i < size; ++i)
+      {
+        freeze(eOperations.get(i));
+      }
+    }
     super.freeze();
   }
   
@@ -131,7 +144,7 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    */
   protected EClass eStaticClass()
   {
-    return EcorePackage.eINSTANCE.getEClass();
+    return EcorePackage.Literals.ECLASS;
   }
 
   /**
@@ -528,25 +541,53 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
-  public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, Class baseClass, NotificationChain msgs)
+  public Object eGet(int featureID, boolean resolve, boolean coreType)
   {
-    if (featureID >= 0)
+    switch (featureID)
     {
-      switch (eDerivedStructuralFeatureID(featureID, baseClass))
-      {
-        case EcorePackage.ECLASS__EANNOTATIONS:
-          return ((InternalEList)getEAnnotations()).basicRemove(otherEnd, msgs);
-        case EcorePackage.ECLASS__EPACKAGE:
-          return eBasicSetContainer(null, EcorePackage.ECLASS__EPACKAGE, msgs);
-        case EcorePackage.ECLASS__EOPERATIONS:
-          return ((InternalEList)getEOperations()).basicRemove(otherEnd, msgs);
-        case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-          return ((InternalEList)getEStructuralFeatures()).basicRemove(otherEnd, msgs);
-        default:
-          return eDynamicInverseRemove(otherEnd, featureID, baseClass, msgs);
-      }
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        return getEAnnotations();
+      case EcorePackage.ECLASS__NAME:
+        return getName();
+      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
+        return getInstanceClassName();
+      case EcorePackage.ECLASS__INSTANCE_CLASS:
+        return getInstanceClass();
+      case EcorePackage.ECLASS__DEFAULT_VALUE:
+        return getDefaultValue();
+      case EcorePackage.ECLASS__EPACKAGE:
+        if (resolve) return getEPackage();
+        return basicGetEPackage();
+      case EcorePackage.ECLASS__ABSTRACT:
+        return isAbstract() ? Boolean.TRUE : Boolean.FALSE;
+      case EcorePackage.ECLASS__INTERFACE:
+        return isInterface() ? Boolean.TRUE : Boolean.FALSE;
+      case EcorePackage.ECLASS__ESUPER_TYPES:
+        return getESuperTypes();
+      case EcorePackage.ECLASS__EOPERATIONS:
+        return getEOperations();
+      case EcorePackage.ECLASS__EALL_ATTRIBUTES:
+        return getEAllAttributes();
+      case EcorePackage.ECLASS__EALL_REFERENCES:
+        return getEAllReferences();
+      case EcorePackage.ECLASS__EREFERENCES:
+        return getEReferences();
+      case EcorePackage.ECLASS__EATTRIBUTES:
+        return getEAttributes();
+      case EcorePackage.ECLASS__EALL_CONTAINMENTS:
+        return getEAllContainments();
+      case EcorePackage.ECLASS__EALL_OPERATIONS:
+        return getEAllOperations();
+      case EcorePackage.ECLASS__EALL_STRUCTURAL_FEATURES:
+        return getEAllStructuralFeatures();
+      case EcorePackage.ECLASS__EALL_SUPER_TYPES:
+        return getEAllSuperTypes();
+      case EcorePackage.ECLASS__EID_ATTRIBUTE:
+        return getEIDAttribute();
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        return getEStructuralFeatures();
     }
-    return eBasicSetContainer(null, featureID, msgs);
+    return eDynamicGet(featureID, resolve, coreType);
   }
 
   /**
@@ -554,19 +595,130 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
    * <!-- end-user-doc -->
    * @generated
    */
-  public NotificationChain eBasicRemoveFromContainer(NotificationChain msgs)
+  public void eSet(int featureID, Object newValue)
   {
-    if (eContainerFeatureID >= 0)
+    switch (featureID)
     {
-      switch (eContainerFeatureID)
-      {
-        case EcorePackage.ECLASS__EPACKAGE:
-          return eContainer.eInverseRemove(this, EcorePackage.EPACKAGE__ECLASSIFIERS, EPackage.class, msgs);
-        default:
-          return eDynamicBasicRemoveFromContainer(msgs);
-      }
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        getEAnnotations().clear();
+        getEAnnotations().addAll((Collection)newValue);
+        return;
+      case EcorePackage.ECLASS__NAME:
+        setName((String)newValue);
+        return;
+      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
+        setInstanceClassName((String)newValue);
+        return;
+      case EcorePackage.ECLASS__ABSTRACT:
+        setAbstract(((Boolean)newValue).booleanValue());
+        return;
+      case EcorePackage.ECLASS__INTERFACE:
+        setInterface(((Boolean)newValue).booleanValue());
+        return;
+      case EcorePackage.ECLASS__ESUPER_TYPES:
+        getESuperTypes().clear();
+        getESuperTypes().addAll((Collection)newValue);
+        return;
+      case EcorePackage.ECLASS__EOPERATIONS:
+        getEOperations().clear();
+        getEOperations().addAll((Collection)newValue);
+        return;
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        getEStructuralFeatures().clear();
+        getEStructuralFeatures().addAll((Collection)newValue);
+        return;
     }
-    return eContainer.eInverseRemove(this, EOPPOSITE_FEATURE_BASE - eContainerFeatureID, null, msgs);
+    eDynamicSet(featureID, newValue);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void eUnset(int featureID)
+  {
+    switch (featureID)
+    {
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        getEAnnotations().clear();
+        return;
+      case EcorePackage.ECLASS__NAME:
+        setName(NAME_EDEFAULT);
+        return;
+      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
+        setInstanceClassName(INSTANCE_CLASS_NAME_EDEFAULT);
+        return;
+      case EcorePackage.ECLASS__ABSTRACT:
+        setAbstract(ABSTRACT_EDEFAULT);
+        return;
+      case EcorePackage.ECLASS__INTERFACE:
+        setInterface(INTERFACE_EDEFAULT);
+        return;
+      case EcorePackage.ECLASS__ESUPER_TYPES:
+        getESuperTypes().clear();
+        return;
+      case EcorePackage.ECLASS__EOPERATIONS:
+        getEOperations().clear();
+        return;
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        getEStructuralFeatures().clear();
+        return;
+    }
+    eDynamicUnset(featureID);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean eIsSet(int featureID)
+  {
+    switch (featureID)
+    {
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        return eAnnotations != null && !eAnnotations.isEmpty();
+      case EcorePackage.ECLASS__NAME:
+        return NAME_EDEFAULT == null ? name != null : !NAME_EDEFAULT.equals(name);
+      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
+        return INSTANCE_CLASS_NAME_EDEFAULT == null ? instanceClassName != null : !INSTANCE_CLASS_NAME_EDEFAULT.equals(instanceClassName);
+      case EcorePackage.ECLASS__INSTANCE_CLASS:
+        return INSTANCE_CLASS_EDEFAULT == null ? getInstanceClass() != null : !INSTANCE_CLASS_EDEFAULT.equals(getInstanceClass());
+      case EcorePackage.ECLASS__DEFAULT_VALUE:
+        return DEFAULT_VALUE_EDEFAULT == null ? getDefaultValue() != null : !DEFAULT_VALUE_EDEFAULT.equals(getDefaultValue());
+      case EcorePackage.ECLASS__EPACKAGE:
+        return basicGetEPackage() != null;
+      case EcorePackage.ECLASS__ABSTRACT:
+        return ((eFlags & ABSTRACT_EFLAG) != 0) != ABSTRACT_EDEFAULT;
+      case EcorePackage.ECLASS__INTERFACE:
+        return ((eFlags & INTERFACE_EFLAG) != 0) != INTERFACE_EDEFAULT;
+      case EcorePackage.ECLASS__ESUPER_TYPES:
+        return eSuperTypes != null && !eSuperTypes.isEmpty();
+      case EcorePackage.ECLASS__EOPERATIONS:
+        return eOperations != null && !eOperations.isEmpty();
+      case EcorePackage.ECLASS__EALL_ATTRIBUTES:
+        return !getEAllAttributes().isEmpty();
+      case EcorePackage.ECLASS__EALL_REFERENCES:
+        return !getEAllReferences().isEmpty();
+      case EcorePackage.ECLASS__EREFERENCES:
+        return !getEReferences().isEmpty();
+      case EcorePackage.ECLASS__EATTRIBUTES:
+        return !getEAttributes().isEmpty();
+      case EcorePackage.ECLASS__EALL_CONTAINMENTS:
+        return !getEAllContainments().isEmpty();
+      case EcorePackage.ECLASS__EALL_OPERATIONS:
+        return !getEAllOperations().isEmpty();
+      case EcorePackage.ECLASS__EALL_STRUCTURAL_FEATURES:
+        return !getEAllStructuralFeatures().isEmpty();
+      case EcorePackage.ECLASS__EALL_SUPER_TYPES:
+        return !getEAllSuperTypes().isEmpty();
+      case EcorePackage.ECLASS__EID_ATTRIBUTE:
+        return getEIDAttribute() != null;
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        return eStructuralFeatures != null && !eStructuralFeatures.isEmpty();
+    }
+    return eDynamicIsSet(featureID);
   }
 
   public EList getEAllContainments()
@@ -622,6 +774,50 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
     return (EStructuralFeatureImpl)eNameToFeatureMap.get(name);
   }
 
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, NotificationChain msgs)
+  {
+    switch (featureID)
+    {
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        return ((InternalEList)getEAnnotations()).basicAdd(otherEnd, msgs);
+      case EcorePackage.ECLASS__EPACKAGE:
+        if (eInternalContainer() != null)
+          msgs = eBasicRemoveFromContainer(msgs);
+        return eBasicSetContainer(otherEnd, EcorePackage.ECLASS__EPACKAGE, msgs);
+      case EcorePackage.ECLASS__EOPERATIONS:
+        return ((InternalEList)getEOperations()).basicAdd(otherEnd, msgs);
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        return ((InternalEList)getEStructuralFeatures()).basicAdd(otherEnd, msgs);
+    }
+    return eDynamicInverseAdd(otherEnd, featureID, msgs);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs)
+  {
+    switch (featureID)
+    {
+      case EcorePackage.ECLASS__EANNOTATIONS:
+        return ((InternalEList)getEAnnotations()).basicRemove(otherEnd, msgs);
+      case EcorePackage.ECLASS__EPACKAGE:
+        return eBasicSetContainer(null, EcorePackage.ECLASS__EPACKAGE, msgs);
+      case EcorePackage.ECLASS__EOPERATIONS:
+        return ((InternalEList)getEOperations()).basicRemove(otherEnd, msgs);
+      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
+        return ((InternalEList)getEStructuralFeatures()).basicRemove(otherEnd, msgs);
+    }
+    return eDynamicInverseRemove(otherEnd, featureID, msgs);
+  }
+
   protected EStructuralFeature[] getEAllStructuralFeaturesData()
   {
     if (eAllStructuralFeaturesData == null)
@@ -672,36 +868,6 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
     return -1;
   }
 
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, Class baseClass, NotificationChain msgs)
-  {
-    if (featureID >= 0)
-    {
-      switch (eDerivedStructuralFeatureID(featureID, baseClass))
-      {
-        case EcorePackage.ECLASS__EANNOTATIONS:
-          return ((InternalEList)getEAnnotations()).basicAdd(otherEnd, msgs);
-        case EcorePackage.ECLASS__EPACKAGE:
-          if (eContainer != null)
-            msgs = eBasicRemoveFromContainer(msgs);
-          return eBasicSetContainer(otherEnd, EcorePackage.ECLASS__EPACKAGE, msgs);
-        case EcorePackage.ECLASS__EOPERATIONS:
-          return ((InternalEList)getEOperations()).basicAdd(otherEnd, msgs);
-        case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-          return ((InternalEList)getEStructuralFeatures()).basicAdd(otherEnd, msgs);
-        default:
-          return eDynamicInverseAdd(otherEnd, featureID, baseClass, msgs);
-      }
-    }
-    if (eContainer != null)
-      msgs = eBasicRemoveFromContainer(msgs);
-    return eBasicSetContainer(otherEnd, featureID, msgs);
-  }
-
   /**
    * The default value of the '{@link #isAbstract() <em>Abstract</em>}' attribute.
    * <!-- begin-user-doc -->
@@ -838,190 +1004,6 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
       eNotify(new ENotificationImpl(this, Notification.SET, EcorePackage.ECLASS__INTERFACE, oldInterface, newInterface));
   }
 
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public Object eGet(EStructuralFeature eFeature, boolean resolve)
-  {
-    switch (eDerivedStructuralFeatureID(eFeature))
-    {
-      case EcorePackage.ECLASS__EANNOTATIONS:
-        return getEAnnotations();
-      case EcorePackage.ECLASS__NAME:
-        return getName();
-      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
-        return getInstanceClassName();
-      case EcorePackage.ECLASS__INSTANCE_CLASS:
-        return getInstanceClass();
-      case EcorePackage.ECLASS__DEFAULT_VALUE:
-        return getDefaultValue();
-      case EcorePackage.ECLASS__EPACKAGE:
-        return getEPackage();
-      case EcorePackage.ECLASS__ABSTRACT:
-        return isAbstract() ? Boolean.TRUE : Boolean.FALSE;
-      case EcorePackage.ECLASS__INTERFACE:
-        return isInterface() ? Boolean.TRUE : Boolean.FALSE;
-      case EcorePackage.ECLASS__ESUPER_TYPES:
-        return getESuperTypes();
-      case EcorePackage.ECLASS__EOPERATIONS:
-        return getEOperations();
-      case EcorePackage.ECLASS__EALL_ATTRIBUTES:
-        return getEAllAttributes();
-      case EcorePackage.ECLASS__EALL_REFERENCES:
-        return getEAllReferences();
-      case EcorePackage.ECLASS__EREFERENCES:
-        return getEReferences();
-      case EcorePackage.ECLASS__EATTRIBUTES:
-        return getEAttributes();
-      case EcorePackage.ECLASS__EALL_CONTAINMENTS:
-        return getEAllContainments();
-      case EcorePackage.ECLASS__EALL_OPERATIONS:
-        return getEAllOperations();
-      case EcorePackage.ECLASS__EALL_STRUCTURAL_FEATURES:
-        return getEAllStructuralFeatures();
-      case EcorePackage.ECLASS__EALL_SUPER_TYPES:
-        return getEAllSuperTypes();
-      case EcorePackage.ECLASS__EID_ATTRIBUTE:
-        return getEIDAttribute();
-      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-        return getEStructuralFeatures();
-    }
-    return eDynamicGet(eFeature, resolve);
-  }
-
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public boolean eIsSet(EStructuralFeature eFeature)
-  {
-    switch (eDerivedStructuralFeatureID(eFeature))
-    {
-      case EcorePackage.ECLASS__EANNOTATIONS:
-        return eAnnotations != null && !eAnnotations.isEmpty();
-      case EcorePackage.ECLASS__NAME:
-        return NAME_EDEFAULT == null ? name != null : !NAME_EDEFAULT.equals(name);
-      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
-        return INSTANCE_CLASS_NAME_EDEFAULT == null ? instanceClassName != null : !INSTANCE_CLASS_NAME_EDEFAULT.equals(instanceClassName);
-      case EcorePackage.ECLASS__INSTANCE_CLASS:
-        return INSTANCE_CLASS_EDEFAULT == null ? getInstanceClass() != null : !INSTANCE_CLASS_EDEFAULT.equals(getInstanceClass());
-      case EcorePackage.ECLASS__DEFAULT_VALUE:
-        return DEFAULT_VALUE_EDEFAULT == null ? getDefaultValue() != null : !DEFAULT_VALUE_EDEFAULT.equals(getDefaultValue());
-      case EcorePackage.ECLASS__EPACKAGE:
-        return getEPackage() != null;
-      case EcorePackage.ECLASS__ABSTRACT:
-        return ((eFlags & ABSTRACT_EFLAG) != 0) != ABSTRACT_EDEFAULT;
-      case EcorePackage.ECLASS__INTERFACE:
-        return ((eFlags & INTERFACE_EFLAG) != 0) != INTERFACE_EDEFAULT;
-      case EcorePackage.ECLASS__ESUPER_TYPES:
-        return eSuperTypes != null && !eSuperTypes.isEmpty();
-      case EcorePackage.ECLASS__EOPERATIONS:
-        return eOperations != null && !eOperations.isEmpty();
-      case EcorePackage.ECLASS__EALL_ATTRIBUTES:
-        return !getEAllAttributes().isEmpty();
-      case EcorePackage.ECLASS__EALL_REFERENCES:
-        return !getEAllReferences().isEmpty();
-      case EcorePackage.ECLASS__EREFERENCES:
-        return !getEReferences().isEmpty();
-      case EcorePackage.ECLASS__EATTRIBUTES:
-        return !getEAttributes().isEmpty();
-      case EcorePackage.ECLASS__EALL_CONTAINMENTS:
-        return !getEAllContainments().isEmpty();
-      case EcorePackage.ECLASS__EALL_OPERATIONS:
-        return !getEAllOperations().isEmpty();
-      case EcorePackage.ECLASS__EALL_STRUCTURAL_FEATURES:
-        return !getEAllStructuralFeatures().isEmpty();
-      case EcorePackage.ECLASS__EALL_SUPER_TYPES:
-        return !getEAllSuperTypes().isEmpty();
-      case EcorePackage.ECLASS__EID_ATTRIBUTE:
-        return getEIDAttribute() != null;
-      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-        return eStructuralFeatures != null && !eStructuralFeatures.isEmpty();
-    }
-    return eDynamicIsSet(eFeature);
-  }
-
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public void eSet(EStructuralFeature eFeature, Object newValue)
-  {
-    switch (eDerivedStructuralFeatureID(eFeature))
-    {
-      case EcorePackage.ECLASS__EANNOTATIONS:
-        getEAnnotations().clear();
-        getEAnnotations().addAll((Collection)newValue);
-        return;
-      case EcorePackage.ECLASS__NAME:
-        setName((String)newValue);
-        return;
-      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
-        setInstanceClassName((String)newValue);
-        return;
-      case EcorePackage.ECLASS__ABSTRACT:
-        setAbstract(((Boolean)newValue).booleanValue());
-        return;
-      case EcorePackage.ECLASS__INTERFACE:
-        setInterface(((Boolean)newValue).booleanValue());
-        return;
-      case EcorePackage.ECLASS__ESUPER_TYPES:
-        getESuperTypes().clear();
-        getESuperTypes().addAll((Collection)newValue);
-        return;
-      case EcorePackage.ECLASS__EOPERATIONS:
-        getEOperations().clear();
-        getEOperations().addAll((Collection)newValue);
-        return;
-      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-        getEStructuralFeatures().clear();
-        getEStructuralFeatures().addAll((Collection)newValue);
-        return;
-    }
-    eDynamicSet(eFeature, newValue);
-  }
-
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public void eUnset(EStructuralFeature eFeature)
-  {
-    switch (eDerivedStructuralFeatureID(eFeature))
-    {
-      case EcorePackage.ECLASS__EANNOTATIONS:
-        getEAnnotations().clear();
-        return;
-      case EcorePackage.ECLASS__NAME:
-        setName(NAME_EDEFAULT);
-        return;
-      case EcorePackage.ECLASS__INSTANCE_CLASS_NAME:
-        setInstanceClassName(INSTANCE_CLASS_NAME_EDEFAULT);
-        return;
-      case EcorePackage.ECLASS__ABSTRACT:
-        setAbstract(ABSTRACT_EDEFAULT);
-        return;
-      case EcorePackage.ECLASS__INTERFACE:
-        setInterface(INTERFACE_EDEFAULT);
-        return;
-      case EcorePackage.ECLASS__ESUPER_TYPES:
-        getESuperTypes().clear();
-        return;
-      case EcorePackage.ECLASS__EOPERATIONS:
-        getEOperations().clear();
-        return;
-      case EcorePackage.ECLASS__ESTRUCTURAL_FEATURES:
-        getEStructuralFeatures().clear();
-        return;
-    }
-    eDynamicUnset(eFeature);
-  }
-
   /**
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -1188,4 +1170,10 @@ public class EClassImpl extends EClassifierImpl implements EClass, ESuperAdapter
       }
     }
   }
+
+  public EObject eObjectForURIFragmentSegment(String uriFragmentSegment)
+  {
+    EObject result = eAllStructuralFeaturesData == null ? null : getEStructuralFeature(uriFragmentSegment);
+    return result != null ? result : super.eObjectForURIFragmentSegment(uriFragmentSegment);
+  }
 }
