@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EPackageRegistryImpl.java,v 1.8 2005/06/20 21:05:41 khussey Exp $
+ * $Id: EPackageRegistryImpl.java,v 1.10 2006/05/08 21:21:50 emerks Exp $
  */
 package org.eclipse.emf.ecore.impl;
 
@@ -25,6 +25,7 @@ import java.util.Set;
 import java.util.WeakHashMap;
 
 import org.eclipse.emf.common.EMFPlugin;
+import org.eclipse.emf.ecore.EFactory;
 import org.eclipse.emf.ecore.EPackage;
 
 import org.eclipse.emf.ecore.plugin.EcorePlugin;
@@ -45,7 +46,11 @@ public class EPackageRegistryImpl extends HashMap implements EPackage.Registry
       String className = System.getProperty("org.eclipse.emf.ecore.EPackage.Registry.INSTANCE");
       if (className == null)
       {
-        if (!EMFPlugin.IS_ECLIPSE_RUNNING)
+        if (EcorePlugin.getDefaultRegistryImplementation() != null)
+        {
+          return EcorePlugin.getDefaultRegistryImplementation();
+        }
+        else if (!EMFPlugin.IS_ECLIPSE_RUNNING)
         {
           return new Delegator();
         }
@@ -118,6 +123,33 @@ public class EPackageRegistryImpl extends HashMap implements EPackage.Registry
     }
   }
 
+  /*
+   * Javadoc copied from interface.
+   */
+  public EFactory getEFactory(String nsURI)
+  {
+    Object ePackage = get(nsURI);
+    if (ePackage instanceof EPackage)
+    {
+      EPackage result = (EPackage)ePackage;
+      if (result.getNsURI() == null)
+      {
+        initialize(result);
+      }
+      return result.getEFactoryInstance();
+    }
+    else if (ePackage instanceof EPackage.Descriptor)
+    {
+      EPackage.Descriptor ePackageDescriptor = (EPackage.Descriptor)ePackage;
+      EFactory result = ePackageDescriptor.getEFactory();
+      return result;
+    }
+    else
+    {
+      return delegatedGetEFactory(nsURI);
+    }
+  }
+
   /**
    * Creates a delegating instance.
    */
@@ -139,6 +171,20 @@ public class EPackageRegistryImpl extends HashMap implements EPackage.Registry
     return null;
   }
 
+  /**
+   * Returns the factory from the delegate registry, if there is one.
+   * @return the factory from the delegate registry.
+   */
+  protected EFactory delegatedGetEFactory(String nsURI)
+  {
+    if (delegateRegistry != null)
+    {
+      return delegateRegistry.getEFactory(nsURI);
+    }
+
+    return null;
+  }
+
   /**
    * Returns whether this map or the delegate map contains this key. Note that
    * if there is a delegate map, the result of this method may
@@ -199,6 +245,11 @@ public class EPackageRegistryImpl extends HashMap implements EPackage.Registry
       return delegateRegistry().getEPackage(key);
     }
 
+    public EFactory getEFactory(String key)
+    {
+      return delegateRegistry().getEFactory(key);
+    }
+
     public int size()
     {
       return delegateRegistry().size();
