@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EDataGraphImpl.java,v 1.7 2005/06/08 06:24:25 nickb Exp $
+ * $Id: EDataGraphImpl.java,v 1.11 2005/11/29 15:16:19 emerks Exp $
  */
 package org.eclipse.emf.ecore.sdo.impl;
 
@@ -39,7 +39,6 @@ import org.eclipse.emf.ecore.EClass;
 import org.eclipse.emf.ecore.EClassifier;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.EPackage;
-import org.eclipse.emf.ecore.EStructuralFeature;
 import org.eclipse.emf.ecore.InternalEObject;
 import org.eclipse.emf.ecore.impl.ENotificationImpl;
 import org.eclipse.emf.ecore.impl.EObjectImpl;
@@ -83,6 +82,13 @@ import commonj.sdo.Type;
  */
 public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph, Adapter, EDataGraph.Internal, Serializable
 {
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  private static final long serialVersionUID = 1L;
+
   /**
    * The default value of the '{@link #getResourceSet() <em>Resource Set</em>}' attribute.
    * <!-- begin-user-doc -->
@@ -155,7 +161,7 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
    */
   protected EClass eStaticClass()
   {
-    return SDOPackage.eINSTANCE.getEDataGraph();
+    return SDOPackage.Literals.EDATA_GRAPH;
   }
 
   public boolean isAdapterForType(Object type)
@@ -470,6 +476,38 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
     return EcoreUtil.create(type);
   }
 
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, NotificationChain msgs)
+  {
+    switch (featureID)
+    {
+      case SDOPackage.EDATA_GRAPH__ECHANGE_SUMMARY:
+        if (eChangeSummary != null)
+          msgs = ((InternalEObject)eChangeSummary).eInverseRemove(this, SDOPackage.ECHANGE_SUMMARY__EDATA_GRAPH, EChangeSummary.class, msgs);
+        return basicSetEChangeSummary((EChangeSummary)otherEnd, msgs);
+    }
+    return super.eInverseAdd(otherEnd, featureID, msgs);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs)
+  {
+    switch (featureID)
+    {
+      case SDOPackage.EDATA_GRAPH__ECHANGE_SUMMARY:
+        return basicSetEChangeSummary(null, msgs);
+    }
+    return super.eInverseRemove(otherEnd, featureID, msgs);
+  }
+
   public EDataObject createEDataObject(EType type)
   {
     return SDOUtil.create(type);
@@ -693,53 +731,9 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
    * <!-- end-user-doc -->
    * @generated
    */
-  public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, Class baseClass, NotificationChain msgs)
+  public Object eGet(int featureID, boolean resolve, boolean coreType)
   {
-    if (featureID >= 0)
-    {
-      switch (eDerivedStructuralFeatureID(featureID, baseClass))
-      {
-        case SDOPackage.EDATA_GRAPH__ECHANGE_SUMMARY:
-          if (eChangeSummary != null)
-            msgs = ((InternalEObject)eChangeSummary).eInverseRemove(this, SDOPackage.ECHANGE_SUMMARY__EDATA_GRAPH, EChangeSummary.class, msgs);
-          return basicSetEChangeSummary((EChangeSummary)otherEnd, msgs);
-        default:
-          return eDynamicInverseAdd(otherEnd, featureID, baseClass, msgs);
-      }
-    }
-    if (eContainer != null)
-      msgs = eBasicRemoveFromContainer(msgs);
-    return eBasicSetContainer(otherEnd, featureID, msgs);
-  }
-
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, Class baseClass, NotificationChain msgs)
-  {
-    if (featureID >= 0)
-    {
-      switch (eDerivedStructuralFeatureID(featureID, baseClass))
-      {
-        case SDOPackage.EDATA_GRAPH__ECHANGE_SUMMARY:
-          return basicSetEChangeSummary(null, msgs);
-        default:
-          return eDynamicInverseRemove(otherEnd, featureID, baseClass, msgs);
-      }
-    }
-    return eBasicSetContainer(null, featureID, msgs);
-  }
-
-  /**
-   * <!-- begin-user-doc -->
-   * <!-- end-user-doc -->
-   * @generated
-   */
-  public Object eGet(EStructuralFeature eFeature, boolean resolve)
-  {
-    switch (eDerivedStructuralFeatureID(eFeature))
+    switch (featureID)
     {
       case SDOPackage.EDATA_GRAPH__ROOT_OBJECT:
         return getRootObject();
@@ -754,7 +748,7 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
       case SDOPackage.EDATA_GRAPH__EROOT_OBJECT:
         return getERootObject();
     }
-    return eDynamicGet(eFeature, resolve);
+    return super.eGet(featureID, resolve, coreType);
   }
 
   /**
@@ -762,9 +756,9 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
    * <!-- end-user-doc -->
    * @generated
    */
-  public void eSet(EStructuralFeature eFeature, Object newValue)
+  public void eSet(int featureID, Object newValue)
   {
-    switch (eDerivedStructuralFeatureID(eFeature))
+    switch (featureID)
     {
       case SDOPackage.EDATA_GRAPH__RESOURCE_SET:
         setResourceSet((ResourceSet)newValue);
@@ -776,7 +770,7 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
         setERootObject((EObject)newValue);
         return;
     }
-    eDynamicSet(eFeature, newValue);
+    super.eSet(featureID, newValue);
   }
 
   /**
@@ -784,9 +778,9 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
    * <!-- end-user-doc -->
    * @generated
    */
-  public void eUnset(EStructuralFeature eFeature)
+  public void eUnset(int featureID)
   {
-    switch (eDerivedStructuralFeatureID(eFeature))
+    switch (featureID)
     {
       case SDOPackage.EDATA_GRAPH__RESOURCE_SET:
         setResourceSet(RESOURCE_SET_EDEFAULT);
@@ -798,7 +792,7 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
         setERootObject((EObject)null);
         return;
     }
-    eDynamicUnset(eFeature);
+    super.eUnset(featureID);
   }
 
   /**
@@ -806,9 +800,9 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
    * <!-- end-user-doc -->
    * @generated
    */
-  public boolean eIsSet(EStructuralFeature eFeature)
+  public boolean eIsSet(int featureID)
   {
-    switch (eDerivedStructuralFeatureID(eFeature))
+    switch (featureID)
     {
       case SDOPackage.EDATA_GRAPH__ROOT_OBJECT:
         return getRootObject() != null;
@@ -823,7 +817,7 @@ public class EDataGraphImpl extends EObjectImpl implements EDataGraph, DataGraph
       case SDOPackage.EDATA_GRAPH__EROOT_OBJECT:
         return eRootObject != null;
     }
-    return eDynamicIsSet(eFeature);
+    return super.eIsSet(featureID);
   }
 
   /**
