@@ -1,18 +1,18 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2003-2004 IBM Corporation and others.
+ * Copyright (c) 2003-2005 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Common Public License v1.0
+ * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/cpl-v10.html
+ * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
  *
  * </copyright>
  *
- * $Id: SDOUtil.java,v 1.12 2004/08/18 18:03:01 marcelop Exp $
+ * $Id: SDOUtil.java,v 1.23.2.1 2006/10/25 13:47:17 emerks Exp $
  */
 package org.eclipse.emf.ecore.sdo.util;
 
@@ -23,15 +23,15 @@ import java.io.InvalidObjectException;
 import java.io.ObjectStreamException;
 import java.math.BigDecimal;
 import java.math.BigInteger;
+import java.util.ArrayList;
 import java.util.Date;
-import java.util.Iterator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import org.eclipse.emf.common.util.BasicEList;
-import org.eclipse.emf.common.util.UniqueEList;
 import org.eclipse.emf.common.util.URI;
+import org.eclipse.emf.common.util.UniqueEList;
 import org.eclipse.emf.ecore.EClass;
 import org.eclipse.emf.ecore.EClassifier;
 import org.eclipse.emf.ecore.EDataType;
@@ -46,6 +46,7 @@ import org.eclipse.emf.ecore.sdo.EDataObject;
 import org.eclipse.emf.ecore.sdo.EProperty;
 import org.eclipse.emf.ecore.sdo.EType;
 import org.eclipse.emf.ecore.sdo.SDOFactory;
+import org.eclipse.emf.ecore.sdo.impl.EPropertyImpl;
 import org.eclipse.emf.ecore.util.EcoreUtil;
 import org.eclipse.emf.ecore.util.ExtendedMetaData;
 import org.eclipse.emf.ecore.util.FeatureMap;
@@ -54,6 +55,7 @@ import org.eclipse.emf.ecore.xmi.impl.EMOFResourceFactoryImpl;
 import org.eclipse.emf.ecore.xmi.impl.EcoreResourceFactoryImpl;
 import org.eclipse.emf.ecore.xmi.impl.XMIResourceFactoryImpl;
 import org.eclipse.emf.ecore.xmi.impl.XMLResourceFactoryImpl;
+import org.eclipse.emf.ecore.xml.type.internal.XMLCalendar;
 
 import commonj.sdo.DataGraph;
 import commonj.sdo.DataObject;
@@ -67,14 +69,16 @@ public final class SDOUtil
   public static List getInstanceProperties(EObject eObject)
   {
     List result = new UniqueEList();
-    for (Iterator i = eObject.eClass().getEAllStructuralFeatures().iterator(); i.hasNext(); )
+    EClass eClass = eObject.eClass();
+    for (int i = 0, count = eClass.getFeatureCount(); i < count; ++i)
     {
-      EStructuralFeature eStructuralFeature = (EStructuralFeature)i.next();
+      EStructuralFeature eStructuralFeature = eClass.getEStructuralFeature(i);
       if (FeatureMapUtil.isFeatureMap(eStructuralFeature))
       {
-        for (Iterator j = ((List)eObject.eGet(eStructuralFeature)).iterator(); j.hasNext(); )
+        List features = (List)eObject.eGet(eStructuralFeature);
+        for (int j = 0, size = features.size(); j < size; ++j)
         {
-          FeatureMap.Entry entry = (FeatureMap.Entry)j.next();
+          FeatureMap.Entry entry = (FeatureMap.Entry)features.get(j);
           EStructuralFeature entryFeature = entry.getEStructuralFeature();
           result.add(entryFeature);
         }
@@ -93,18 +97,18 @@ public final class SDOUtil
     if (property == null)
     {
       List instanceProperties = getInstanceProperties(eObject);
-      for (Iterator i = instanceProperties.iterator(); i.hasNext(); )
+      for (int i = 0, size = instanceProperties.size(); i < size; ++i)
       {
-        EStructuralFeature eStructuralFeature = (EStructuralFeature)i.next();
+        EStructuralFeature eStructuralFeature = (EStructuralFeature)instanceProperties.get(i);
         if (eStructuralFeature.getName().equals(propertyName))
         {
           return eStructuralFeature;
         }
       }
 
-      for (Iterator i = instanceProperties.iterator(); i.hasNext(); )
+      for (int i = 0, size = instanceProperties.size(); i < size; ++i)
       {
-        EStructuralFeature eStructuralFeature = (EStructuralFeature)i.next();
+        EStructuralFeature eStructuralFeature = (EStructuralFeature)instanceProperties.get(i);
         if (ExtendedMetaData.INSTANCE.getName(eStructuralFeature).equals(propertyName))
         {
           return eStructuralFeature;
@@ -253,7 +257,7 @@ public final class SDOUtil
 
   protected static EStructuralFeature getFeature(EObject eObject, int propertyIndex)
   {
-    return (EStructuralFeature)eObject.eClass().getEAllStructuralFeatures().get(propertyIndex);
+    return eObject.eClass().getEStructuralFeature(propertyIndex);
   }
 
   public static Object get(EObject eObject, int propertyIndex)
@@ -323,7 +327,7 @@ public final class SDOUtil
 
   public static DataObject getDataObject(EObject eObject, Property property)
   {
-    return (DataObject)get(eObject, ((EProperty)property).getEStructuralFeature());
+    return (DataObject)get(eObject, ((EPropertyImpl)property).getEStructuralFeature());
   }
 
   public static List getList(EObject eObject, Property property)
@@ -338,7 +342,7 @@ public final class SDOUtil
 
   public static void setDataObject(EObject eObject, Property property, DataObject value)
   {
-    set(eObject, ((EProperty)property).getEStructuralFeature(), value);
+    set(eObject, ((EPropertyImpl)property).getEStructuralFeature(), value);
   }
 
   public static void setList(EObject eObject, Property property, List value)
@@ -449,10 +453,15 @@ public final class SDOUtil
   public static void delete(EObject eObject)
   {
     EcoreUtil.remove(eObject);
-    List eAllStructuralFeatures = eObject.eClass().getEAllStructuralFeatures();
-    for (int i = 0, size = eAllStructuralFeatures.size(); i < size; ++i)
+    List contents = new ArrayList(eObject.eContents());
+    for (int i = 0, size = contents.size(); i < size; ++i)
     {
-      EStructuralFeature eStructuralFeature = (EStructuralFeature)eAllStructuralFeatures.get(i);
+      delete((EObject)contents.get(i));
+    }
+    EClass eClass = eObject.eClass();
+    for (int i = 0, size = eClass.getFeatureCount(); i < size; ++i)
+    {
+      EStructuralFeature eStructuralFeature = eClass.getEStructuralFeature(i);
       if (eStructuralFeature.isChangeable() && !eStructuralFeature.isDerived() && !adaptProperty(eStructuralFeature).isReadOnly())
       {
         eObject.eUnset(eStructuralFeature);
@@ -467,7 +476,8 @@ public final class SDOUtil
 
   public static EProperty getContainmentProperty(EObject eObject)
   {
-    return adaptProperty(eObject.eContainmentFeature());
+    EReference eContainmentFeature = eObject.eContainmentFeature();
+    return eContainmentFeature == null ? null : adaptProperty(eContainmentFeature);
   }
 
   public static EDataGraph getEDataGraph(EObject eObject)
@@ -640,7 +650,7 @@ public final class SDOUtil
     }
 
     /**
-     * Only the get and recyle methods should be call; they are the only synchronized methods.
+     * Only the get and recycle methods should be call; they are the only synchronized methods.
      */
     protected static class Pool extends BasicEList
     {
@@ -750,8 +760,9 @@ public final class SDOUtil
 
     public Object getAndRecyle()
     {
-      pool.recycle(this);
-      return get();
+      Object result = get();
+      recycle();
+      return result;
     }
 
     public void set(Object newValue)
@@ -770,8 +781,8 @@ public final class SDOUtil
 
     public void setAndRecyle(Object newValue)
     {
-      pool.recycle(this);
       set(newValue);
+      recycle();
     }
 
     public boolean isSet()
@@ -781,8 +792,9 @@ public final class SDOUtil
 
     public boolean isSetAndRecyle()
     {
-      pool.recycle(this);
-      return isSet();
+      boolean result = isSet();
+      recycle();
+      return result;
     }
 
     public void unset()
@@ -792,12 +804,14 @@ public final class SDOUtil
 
     public void unsetAndRecyle()
     {
-      pool.recycle(this);
       unset();
+      recycle();
     }
 
     public void recycle()
     {
+      eObject = null;
+      feature = null;
       pool.recycle(this);
     }
 
@@ -839,9 +853,9 @@ public final class SDOUtil
     protected void setIndex(int index)
     {
       this.index = index;
-      if (index > 0 && !FeatureMapUtil.isMany(eObject, feature))
+      if (!FeatureMapUtil.isMany(eObject, feature))
       {
-        throw new IndexOutOfBoundsException("Index applies only to mutli-valued features.");
+        throw new IndexOutOfBoundsException("Index applies only to multi-valued features.");
       }
     }
 
@@ -1138,7 +1152,7 @@ public final class SDOUtil
         result.put("xmi", new XMIResourceFactoryImpl());
       }
 
-      if (resourceSet.getResourceFactoryRegistry().getFactory(URI.createURI("*.xml")) == null)
+      if (resourceSet.getResourceFactoryRegistry().getFactory(URI.createURI("*.*")) == null)
       {
         result.put("*", new XMLResourceFactoryImpl());
       }
@@ -1169,7 +1183,7 @@ public final class SDOUtil
 
   public static BigDecimal getBigDecimal(EObject eObject, Property property)
   {
-    return getBigDecimal(get(eObject, ((EProperty)property).getEStructuralFeature()));
+    return getBigDecimal(get(eObject, ((EPropertyImpl)property).getEStructuralFeature()));
   }
 
   public static BigDecimal getBigDecimal(EObject eObject, String path)
@@ -1189,6 +1203,11 @@ public final class SDOUtil
       return new BigDecimal((BigInteger)value);
     }
 
+    if (value instanceof Long)
+    {
+      return new BigDecimal(((Long)value).longValue());
+    }
+
     if (value instanceof Number)
     {
       return new BigDecimal(((Number)value).doubleValue());
@@ -1249,53 +1268,53 @@ public final class SDOUtil
     {
       return eType.getDefaultValue();
     }
-    
+
     String name = eType.getInstanceClassName();
     if (name == "java.math.BigDecimal")
     {
       return value;
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return value.toBigInteger();
     }
-    
+
     if (name == "java.lang.Byte" || name == "byte")
     {
       return new Byte(value.byteValue());
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value.doubleValue());
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value.floatValue());
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer(value.intValue());
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value.longValue());
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short(value.shortValue());
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value;
   }
@@ -1383,8 +1402,8 @@ public final class SDOUtil
         accessor.setAndRecyle(getSetValue(accessor.getEStructuralFeature(), value));
       }
     }
-  }  
-  
+  }
+
   protected static Object getSetValue(EStructuralFeature eStructuralFeature, BigInteger value)
   {
     EClassifier eType = eStructuralFeature.getEType();
@@ -1398,52 +1417,52 @@ public final class SDOUtil
     {
       return value;
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return new BigDecimal(value);
     }
-    
+
     if (name == "java.lang.Byte" || name == "byte")
     {
       return new Byte(value.byteValue());
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value.doubleValue());
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value.floatValue());
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer(value.intValue());
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value.longValue());
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short(value.shortValue());
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     if (name == "byte[]")
     {
       return value.toByteArray();
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value;
   }
@@ -1484,7 +1503,7 @@ public final class SDOUtil
   }
 
   public static void setBoolean(EObject eObject, int propertyIndex, boolean value)
-  {    
+  {
     EStructuralFeature eStructuralFeature = getFeature(eObject, propertyIndex);
     set(eObject, eStructuralFeature, getSetValue(eStructuralFeature, value));
   }
@@ -1525,12 +1544,12 @@ public final class SDOUtil
     {
       return value ? Boolean.TRUE : Boolean.FALSE;
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value ? Boolean.TRUE : Boolean.FALSE;
   }
@@ -1604,7 +1623,7 @@ public final class SDOUtil
       }
     }
   }
-  
+
   protected static Object getSetValue(EStructuralFeature eStructuralFeature, byte value)
   {
     String name = eStructuralFeature.getEType().getInstanceClassName();
@@ -1612,47 +1631,47 @@ public final class SDOUtil
     {
       return new Byte(value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer(value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short(value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Byte(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Byte(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Byte(value);
   }
@@ -1730,22 +1749,22 @@ public final class SDOUtil
   protected static Object getSetValue(EStructuralFeature eStructuralFeature, byte[] value)
   {
     EClassifier eType = eStructuralFeature.getEType();
-    if(value == null)
+    if (value == null)
     {
       return eType.getDefaultValue();
     }
-    
+
     String name = eType.getInstanceClassName();
     if (name == "byte[]")
     {
       return value;
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return new BigInteger(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value;
   }
@@ -1827,12 +1846,12 @@ public final class SDOUtil
     {
       return new Character(value);
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Character(value);
   }
@@ -1854,6 +1873,11 @@ public final class SDOUtil
 
   protected static Date getDate(Object value)
   {
+    if (value instanceof XMLCalendar)
+    {
+      return ((XMLCalendar)value).getDate();
+    }
+
     if (value instanceof Date)
     {
       return (Date)value;
@@ -1916,20 +1940,65 @@ public final class SDOUtil
     }
 
     String name = eType.getInstanceClassName();
-    if (name == "java.util.Date")
+    if (name == "java.lang.Object")
     {
+      String typeName = getDateTypeName((EDataType)eType);
+      if ("Date".equals(typeName))
+      {
+        return new XMLCalendar(value, XMLCalendar.DATE);
+      }
+      if ("DateTime".equals(typeName))
+      {
+        return new XMLCalendar(value, XMLCalendar.DATETIME);
+      }
+      // Instead of throwing an IllegalArgumentException we are passing the value to the feature
       return value;
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value.getTime());
     }
-    
-    //Instead of throwing an IllegalArgumentException we are passing the value to the feature
+    if (name == "java.lang.String")
+    {
+      return value.toString();
+    }
+
+    // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value;
   }
 
+  protected static String getDateTypeName(EDataType eDataType)
+  {
+    String name = eDataType.getName();
+    if (("DateTime".equals(name)) || ("Date".equals(name)))
+    {
+      return name;
+    }
+
+    EDataType baseType = ExtendedMetaData.INSTANCE.getBaseType(eDataType);
+    if (baseType != null)
+    {
+      return getDateTypeName(baseType);
+    }
+
+    List memberTypes = ExtendedMetaData.INSTANCE.getMemberTypes(eDataType);
+    if (!memberTypes.isEmpty())
+    {
+      for (int i = 0, size = memberTypes.size(); i < size; ++i)
+      {
+        EDataType memberType = (EDataType)memberTypes.get(i);
+        String memberTypeName = getDateTypeName(memberType);
+        if (("DateTime".equals(memberTypeName)) || ("Date".equals(memberTypeName)))
+        {
+          return memberTypeName;
+        }
+      }
+    }
+
+    return "";
+  }
+
   public static double getDouble(EObject eObject, int propertyIndex)
   {
     return getDouble(get(eObject, getFeature(eObject, propertyIndex)));
@@ -2007,47 +2076,47 @@ public final class SDOUtil
     {
       return new Byte((byte)value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer((int)value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long((long)value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short((short)value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Double(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Double(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     //Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Double(value);
   }
@@ -2129,47 +2198,47 @@ public final class SDOUtil
     {
       return new Byte((byte)value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer((int)value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long((long)value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short((short)value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Float(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Float(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Float(value);
   }
@@ -2251,47 +2320,47 @@ public final class SDOUtil
     {
       return new Byte((byte)value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer(value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short((short)value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Integer(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Integer(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Integer(value);
   }
@@ -2378,52 +2447,52 @@ public final class SDOUtil
     {
       return new Byte((byte)value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer((int)value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short((short)value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Long(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Long(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     if (name == "java.util.Date")
     {
       return new Date(value);
     }
-    
+
     // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Long(value);
   }
@@ -2505,47 +2574,47 @@ public final class SDOUtil
     {
       return new Byte((byte)value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double")
     {
       return new Double(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return new Integer(value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return new Long(value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return new Short(value);
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(new Short(value));
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(new Short(value));
     }
-    
+
     if (name == "java.lang.String")
     {
       return String.valueOf(value);
     }
-    
+
     // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return new Short(value);
   }
@@ -2598,7 +2667,7 @@ public final class SDOUtil
   }
 
   public static void setString(EObject eObject, String path, String value)
-  {   
+  {
     EStructuralFeature eStructuralFeature = eObject.eClass().getEStructuralFeature(path);
     if (eStructuralFeature != null)
     {
@@ -2616,8 +2685,8 @@ public final class SDOUtil
       {
         Accessor accessor = Accessor.create(eObject, path);
         accessor.setAndRecyle(getSetValue(accessor.getEStructuralFeature(), value));
-      }     
-    }   
+      }
+    }
   }
 
   protected static Object getSetValue(EStructuralFeature eStructuralFeature, String value)
@@ -2633,57 +2702,57 @@ public final class SDOUtil
     {
       return value;
     }
-    
+
     if (name == "java.lang.Byte" || name == "byte")
     {
       return Byte.valueOf(value);
     }
-    
+
     if (name == "java.lang.Double" || name == "double" || name == "java.lang.Number")
     {
       return Double.valueOf(value);
     }
-    
+
     if (name == "java.lang.Float" || name == "float")
     {
       return new Float(value);
     }
-    
+
     if (name == "java.lang.Integer" || name == "int")
     {
       return Integer.valueOf(value);
     }
-    
+
     if (name == "java.lang.Long" || name == "long")
     {
       return Long.valueOf(value);
     }
-    
+
     if (name == "java.lang.Short" || name == "short")
     {
       return Short.valueOf(value);
     }
-    
+
     if (name == "java.lang.Character" || name == "char")
     {
       return new Character(value.charAt(0));
     }
-    
+
     if (name == "java.math.BigDecimal")
     {
       return getBigDecimal(value);
     }
-    
+
     if (name == "java.math.BigInteger")
     {
       return getBigInteger(value);
     }
-    
+
     if (name == "java.lang.Boolean" || name == "boolean")
     {
       return Boolean.valueOf(value);
     }
-    
+
     // Instead of throwing an IllegalArgumentException we are passing the value to the feature
     return value;
   }
