@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: BasicExtendedMetaData.java,v 1.20 2005/06/08 06:20:10 nickb Exp $
+ * $Id: BasicExtendedMetaData.java,v 1.26.2.1 2006/12/09 18:43:05 emerks Exp $
  */
 package org.eclipse.emf.ecore.util;
 
@@ -41,6 +41,7 @@ import org.eclipse.emf.ecore.ETypedElement;
 import org.eclipse.emf.ecore.EcoreFactory;
 import org.eclipse.emf.ecore.EcorePackage;
 import org.eclipse.emf.ecore.xml.type.XMLTypePackage;
+import org.eclipse.emf.ecore.xml.type.internal.DataValue;
 
 
 /**
@@ -110,16 +111,7 @@ public class BasicExtendedMetaData implements ExtendedMetaData
 
   public EClassifier getType(EPackage ePackage, String name)
   {
-    List eClassifiers = ePackage.getEClassifiers();
-    for (int i = 0, size = eClassifiers.size(); i < size; ++i)
-    {
-      EClassifier eClassifier = (EClassifier)eClassifiers.get(i);
-      if (name.equals(getName(eClassifier)))
-      {
-        return eClassifier;
-      }
-    }
-    return null;
+    return getExtendedMetaData(ePackage).getType(name);
   }
 
   public EPackage getPackage(String namespace)
@@ -307,6 +299,11 @@ public class BasicExtendedMetaData implements ExtendedMetaData
     EAnnotation eAnnotation = getAnnotation(eClassifier, true);
     eAnnotation.getDetails().put("name", name);
     getExtendedMetaData(eClassifier).setName(name);
+    EPackage ePackage = eClassifier.getEPackage();
+    if (ePackage != null)
+    {
+      getExtendedMetaData(ePackage).rename(eClassifier, name);
+    }
   }
 
   public boolean isAnonymous(EClassifier eClassifier)
@@ -1584,7 +1581,7 @@ public class BasicExtendedMetaData implements ExtendedMetaData
       EAnnotation eAnnotation = getAnnotation(eDataType, false);
       if (eAnnotation != null)
       {
-        eAnnotation.getDetails().remove("factionDigits");
+        eAnnotation.getDetails().remove("fractionDigits");
       }
     }
     else
@@ -1849,7 +1846,7 @@ public class BasicExtendedMetaData implements ExtendedMetaData
              namespace.equals(ExtendedMetaData.XML_URI) ?
                "xml" : 
                "xmlns" : 
-             "_");
+             computePrefix(namespace));
       }
       demandRegistry.put(namespace, ePackage);
 
@@ -1863,6 +1860,50 @@ public class BasicExtendedMetaData implements ExtendedMetaData
     }
     return ePackage;
   }
+  
+  protected String computePrefix(String namespace)
+  {
+    int index = namespace.length();
+    boolean containsLetter = false;
+    StringBuffer prefix = new StringBuffer(index);
+    while (--index >= 0)
+    {
+      char character = namespace.charAt(index);
+      if (DataValue.XMLChar.isNCName(character))
+      {
+        prefix.append(character);
+        containsLetter = Character.isLetter(character);
+        break;
+      }
+    }
+    while (--index >= 0)
+    {
+      char character = namespace.charAt(index);
+      if (DataValue.XMLChar.isNCName(character))
+      {
+        prefix.append(character);
+        if (!containsLetter)
+        {
+          containsLetter = Character.isLetter(character);
+        }
+      }
+      else if (!containsLetter)
+      {
+        prefix.append('_');
+      }
+      else
+      {
+        break;
+      }
+    }
+    
+    int length = prefix.length();
+    if (length == 0 || !DataValue.XMLChar.isNCNameStart(prefix.charAt(length - 1)))
+    {
+      prefix.append('_');
+    }
+    return prefix.reverse().toString();
+  }
 
   public EClassifier demandType(String namespace, String name)
   {
@@ -1971,6 +2012,10 @@ public class BasicExtendedMetaData implements ExtendedMetaData
 
     boolean isQualified();
     void setQualified(boolean isQualified);
+
+    EClassifier getType(String name);
+
+    void rename(EClassifier eClassifier, String newName);
   }
 
   public class EPackageExtendedMetaDataImpl implements EPackageExtendedMetaData
@@ -1978,6 +2023,7 @@ public class BasicExtendedMetaData implements ExtendedMetaData
     protected EPackage ePackage;
     protected boolean isInitialized;
     protected boolean isQualified;
+    protected Map nameToClassifierMap;
 
     public EPackageExtendedMetaDataImpl(EPackage ePackage)
     {
@@ -1998,6 +2044,65 @@ public class BasicExtendedMetaData implements ExtendedMetaData
       this.isQualified = isQualified;
       isInitialized = true;
     }
+    
+    public EClassifier getType(String name)
+    {
+      EClassifier result = null;
+      if (nameToClassifierMap != null)
+      {
+        result = (EClassifier)nameToClassifierMap.get(name);
+      }
+      if (result == null)
+      {
+        Map nameToClassifierMap = new HashMap();
+        if (this.nameToClassifierMap != null)
+        {
+          nameToClassifierMap.putAll(this.nameToClassifierMap);
+        }
+
+        // For demand created created packages we allow the list of classifiers to grow 
+        // so this should handle those additional instances.
+        //
+        List eClassifiers = ePackage.getEClassifiers();
+        for (int i = nameToClassifierMap.size(), size = eClassifiers.size(); i < size; ++i)
+        {
+          EClassifier eClassifier = (EClassifier)eClassifiers.get(i);
+          String eClassifierName = getName(eClassifier);
+          Object conflictingEClassifier = nameToClassifierMap.put(eClassifierName, eClassifier);
+          if (conflictingEClassifier != null && conflictingEClassifier != eClassifier)
+          {
+            nameToClassifierMap.put(eClassifierName, conflictingEClassifier);
+          }
+        }
+
+        if (nameToClassifierMap.size() != eClassifiers.size())
+        {
+          for (int i = 0, size = eClassifiers.size(); i < size; ++i)
+          {
+            EClassifier eClassifier = (EClassifier)eClassifiers.get(i);
+            String eClassifierName = getName(eClassifier);
+            Object conflictingEClassifier = nameToClassifierMap.put(eClassifierName, eClassifier);
+            if (conflictingEClassifier != null && conflictingEClassifier != eClassifier)
+            {
+              nameToClassifierMap.put(eClassifierName, conflictingEClassifier);
+            }
+          }
+        }
+        result = (EClassifier)nameToClassifierMap.get(name);
+        this.nameToClassifierMap = nameToClassifierMap;
+      }
+
+      return result;
+    }
+
+    public void rename(EClassifier eClassifier, String newName)
+    {
+      if (nameToClassifierMap != null)
+      {
+        nameToClassifierMap.values().remove(eClassifier);
+        nameToClassifierMap.put(newName, eClassifier);
+      }
+    }
   }
 
   protected EPackageExtendedMetaData getExtendedMetaData(EPackage ePackage)
