@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EContentsEList.java,v 1.5 2005/06/08 06:20:10 nickb Exp $
+ * $Id: EContentsEList.java,v 1.9 2006/05/12 21:07:22 emerks Exp $
  */
 package org.eclipse.emf.ecore.util;
 
@@ -23,6 +23,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.NoSuchElementException;
+import java.util.RandomAccess;
 
 import org.eclipse.emf.common.notify.NotificationChain;
 import org.eclipse.emf.common.util.EList;
@@ -34,6 +35,26 @@ import org.eclipse.emf.ecore.impl.EClassImpl;
 
 public class EContentsEList extends AbstractSequentialList implements EList, InternalEList
 {
+  public static final EContentsEList EMPTY_CONTENTS_ELIST = 
+    new EContentsEList(null, (EStructuralFeature [])null)
+    {
+      public List basicList()
+      {
+        return this;
+      }
+    }; 
+
+  public static EContentsEList createEContentsEList(EObject eObject)
+  {
+    EStructuralFeature [] eStructuralFeatures = 
+      ((EClassImpl.FeatureSubsetSupplier)eObject.eClass().getEAllStructuralFeatures()).containments();
+    
+    return 
+      eStructuralFeatures == null ?
+        EMPTY_CONTENTS_ELIST:
+        new EContentsEList(eObject, eStructuralFeatures);
+  }
+
   protected final EObject eObject; 
   protected final EStructuralFeature [] eStructuralFeatures;
 
@@ -59,10 +80,17 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
 
   protected ListIterator newListIterator()
   {
-    return
-      resolve() ?
-        new ResolvingFeatureIteratorImpl(eObject, eStructuralFeatures) :
-        new FeatureIteratorImpl(eObject, eStructuralFeatures);
+    return resolve() ? newResolvingListIterator() : newNonResolvingListIterator();
+  }
+  
+  protected ListIterator newResolvingListIterator()
+  {
+    return new ResolvingFeatureIteratorImpl(eObject, eStructuralFeatures);
+  }
+  
+  protected ListIterator newNonResolvingListIterator()
+  {
+    return new FeatureIteratorImpl(eObject, eStructuralFeatures);
   }
 
   protected Iterator newIterator()
@@ -229,7 +257,7 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
       return FeatureIteratorImpl.EMPTY_ITERATOR;
     }
 
-    return new FeatureIteratorImpl(eObject, eStructuralFeatures);
+    return newNonResolvingListIterator();
   }
 
   public ListIterator basicListIterator()
@@ -239,7 +267,7 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
       return FeatureIteratorImpl.EMPTY_ITERATOR;
     }
 
-    return new FeatureIteratorImpl(eObject, eStructuralFeatures);
+    return newNonResolvingListIterator();
   }
 
   public ListIterator basicListIterator(int index)
@@ -254,7 +282,7 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
       return FeatureIteratorImpl.EMPTY_ITERATOR;
     }
 
-    ListIterator result = new FeatureIteratorImpl(eObject, eStructuralFeatures);
+    ListIterator result = newNonResolvingListIterator();
     for (int i = 0; i < index; ++i)
     {
       result.next();
@@ -308,6 +336,10 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
     protected EStructuralFeature feature;
     protected boolean isHandlingFeatureMap;
     protected ListIterator values;
+    protected InternalEList valueInternalEList;
+    protected List valueList;
+    protected int valueListSize;
+    protected int valueListIndex;
 
     public FeatureIteratorImpl(EObject eObject, List eStructuralFeatures)
     {
@@ -363,11 +395,18 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
         case -3:
         {
           // Undo the preparation for previous and continue.
-          values.next();
+          if (values == null)
+          {
+            ++valueListIndex;
+          }
+          else
+          {
+            values.next();
+          }
         }
         default:
         {
-          if (values == null || !scanNext(values))
+          if (valueList == null || (values == null ? !scanNext() : !scanNext(values)))
           {
             while (featureCursor < eStructuralFeatures.length)
             {
@@ -378,21 +417,45 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
                 isHandlingFeatureMap = FeatureMapUtil.isFeatureMap(feature);
                 if (isHandlingFeatureMap || feature.isMany())
                 {
-                  values = resolve() ? ((List)value).listIterator() : ((InternalEList)value).basicListIterator();
-                  if (scanNext(values))
+                  valueList = resolve() ? (List)value : (valueInternalEList = (InternalEList)value);
+                  if (valueList instanceof RandomAccess)
                   {
-                    preparedResult = values.next();
+                    values = null;
+                    valueListSize = valueList.size();
+                    valueListIndex = 0;
+                  }
+                  else
+                  {
+                    values = 
+                      valueInternalEList == null ? 
+                        valueList.listIterator() : 
+                        valueInternalEList.basicListIterator();
+                  }
+                  if (values == null ? scanNext() : scanNext(values))
+                  {
+                    preparedResult = 
+                       values == null ? 
+                         valueInternalEList == null ? 
+                           valueList.get(valueListIndex++) : 
+                           valueInternalEList.basicGet(valueListIndex++) : 
+                         values.next();
                     if (isHandlingFeatureMap)
                     {
-                      preparedResult = ((FeatureMap.Entry)preparedResult).getValue();
+                      FeatureMap.Entry entry = (FeatureMap.Entry)preparedResult; 
+                      preparedFeature = entry.getEStructuralFeature();
+                      preparedResult = entry.getValue();
+                    }
+                    else
+                    {
+                      preparedFeature = feature;
                     }
-                    preparedFeature = feature;
                     prepared = 3;
                     return true;
                   }
                 }
                 else if (value != null)
                 {
+                  valueList = null;
                   values = null;
                   preparedResult = value;
                   preparedFeature = feature;
@@ -401,6 +464,7 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
                 }
               }
             }
+            valueList = null;
             values = null;
             isHandlingFeatureMap = false;
             prepared = 1;
@@ -408,10 +472,17 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
           }
           else
           {
-            preparedResult = values.next();
+            preparedResult = 
+              values == null ? 
+                valueInternalEList == null ? 
+                  valueList.get(valueListIndex++) : 
+                  valueInternalEList.basicGet(valueListIndex++) : 
+                values.next();
             if (isHandlingFeatureMap)
             {
-              preparedResult = ((FeatureMap.Entry)preparedResult).getValue();
+              FeatureMap.Entry entry = (FeatureMap.Entry)preparedResult; 
+              preparedFeature = entry.getEStructuralFeature();
+              preparedResult = entry.getValue();
             }
             prepared = 3;
             return true;
@@ -442,14 +513,41 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
       }
     }
 
+    protected boolean scanNext()
+    {
+      if (isHandlingFeatureMap)
+      {
+        while (valueListIndex < valueListSize)
+        {
+          FeatureMap.Entry entry = (FeatureMap.Entry)valueList.get(valueListIndex);
+          EStructuralFeature entryFeature = entry.getEStructuralFeature();
+          if (isIncludedEntry(entryFeature) && entry.getValue() != null)
+          {
+            return true;
+          }
+          else
+          {
+            ++valueListIndex;
+          }
+        }
+        return false;
+      }
+      else
+      {
+        return valueListIndex < valueListSize;
+      }
+    }
+
     public Object next()
     {
-      if (hasNext())
+      if (prepared > 1 || hasNext())
       {
         ++cursor;
         prepared = 0;
         feature = preparedFeature;
-        return preparedResult;
+        Object result = preparedResult;
+        hasNext();
+        return result;
       }
       else
       {
@@ -478,11 +576,18 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
         case 3:
         {
           // Undo the preparation for next and continue.
-          values.previous();
+          if (values == null)
+          {
+            --valueListIndex;
+          }
+          else
+          {
+            values.previous();
+          }
         }
         default:
         {
-          if (values == null || !scanPrevious(values))
+          if (valueList == null || (values == null ? !scanPrevious() : !scanPrevious(values)))
           {
             while (featureCursor > 0)
             {
@@ -493,22 +598,44 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
                 isHandlingFeatureMap = FeatureMapUtil.isFeatureMap(feature);
                 if (isHandlingFeatureMap || feature.isMany())
                 {
-                  List list = (List)value;
-                  values = resolve() ? list.listIterator(list.size()) : ((InternalEList)list).basicListIterator(list.size());
-                  if (scanPrevious(values))
+                  valueList = resolve() ? (List)value : (valueInternalEList = (InternalEList)value);
+                  if (valueList instanceof RandomAccess)
                   {
-                    preparedResult = values.previous();
+                    valueListSize = valueList.size();
+                    valueListIndex = valueListSize;
+                  }
+                  else
+                  {
+                    values = 
+                      valueInternalEList == null ? 
+                        valueList.listIterator(valueList.size()) : 
+                        valueInternalEList.basicListIterator(valueList.size());
+                  }
+                  if (values == null ? scanPrevious() : scanPrevious(values))
+                  {
+                    preparedResult = 
+                      values == null ? 
+                        valueInternalEList == null ? 
+                          valueList.get(--valueListIndex) : 
+                          valueInternalEList.basicGet(--valueListIndex) : 
+                        values.previous();
                     if (isHandlingFeatureMap)
                     {
-                      preparedResult = ((FeatureMap.Entry)preparedResult).getValue();
+                      FeatureMap.Entry entry = (FeatureMap.Entry)preparedResult; 
+                      preparedFeature = entry.getEStructuralFeature();
+                      preparedResult = entry.getValue();
+                    }
+                    else
+                    {
+                      preparedFeature = feature;
                     }
-                    preparedFeature = feature;
                     prepared = -3;
                     return true;
                   }
                 }
                 else if (value != null)
                 {
+                  valueList = null;
                   values = null;
                   preparedResult = value;
                   preparedFeature = feature;
@@ -517,16 +644,24 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
                 }
               }
             }
+            valueList = null;
             values = null;
             prepared = -1;
             return false;
           }
           else
           {
-            preparedResult = values.previous();
+            preparedResult = 
+              values == null ? 
+                valueInternalEList == null ? 
+                  valueList.get(--valueListIndex) : 
+                  valueInternalEList.basicGet(--valueListIndex) : 
+                values.previous();
             if (isHandlingFeatureMap)
             {
-              preparedResult = ((FeatureMap.Entry)preparedResult).getValue();
+              FeatureMap.Entry entry = (FeatureMap.Entry)preparedResult; 
+              preparedFeature = entry.getEStructuralFeature();
+              preparedResult = entry.getValue();
             }
             prepared = -3;
             return true;
@@ -557,14 +692,41 @@ public class EContentsEList extends AbstractSequentialList implements EList, Int
       }
     }
 
+    protected boolean scanPrevious()
+    {
+      if (isHandlingFeatureMap)
+      {
+        while (valueListIndex > 0)
+        {
+          FeatureMap.Entry entry = (FeatureMap.Entry)valueList.get(valueListIndex - 1);
+          EStructuralFeature entryFeature = entry.getEStructuralFeature();
+          if (isIncludedEntry(entryFeature) && entry.getValue() != null)
+          {
+            return true;
+          }
+          else
+          {
+            --valueListIndex;
+          }
+        }
+        return false;
+      }
+      else
+      {
+        return valueListIndex > 0;
+      }
+    }
+
     public Object previous()
     {
-      if (hasPrevious())
+      if (prepared < -1 || hasPrevious())
       {
         --cursor;
         prepared = 0;
         feature = preparedFeature;
-        return preparedResult;
+        Object result = preparedResult;
+        hasPrevious();
+        return result;
       }
       else
       {
