@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2004-2005 IBM Corporation and others.
+ * Copyright (c) 2004-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EObjectValidator.java,v 1.11 2005/06/08 06:20:10 nickb Exp $
+ * $Id: EObjectValidator.java,v 1.15 2006/01/20 16:17:51 marcelop Exp $
  */
 package org.eclipse.emf.ecore.util;
 
@@ -30,6 +30,7 @@ import java.math.BigDecimal;
 import org.eclipse.emf.common.util.BasicDiagnostic;
 import org.eclipse.emf.common.util.Diagnostic;
 import org.eclipse.emf.common.util.DiagnosticChain;
+import org.eclipse.emf.common.util.ResourceLocator;
 
 import org.eclipse.emf.ecore.EValidator;
 
@@ -69,6 +70,7 @@ public class EObjectValidator implements EValidator
   public static final int DATA_VALUE__MATCHES_PATTERN = 9;
   public static final int DATA_VALUE__TOTAL_DIGITS_IN_RANGE = 10;
   public static final int DATA_VALUE__FRACTION_DIGITS_IN_RANGE = 11;
+  public static final int EOBJECT__UNIQUE_ID = 12;
 
   /**
    * @since 2.1.0
@@ -188,6 +190,10 @@ public class EObjectValidator implements EValidator
     {
       result &= validate_EveryDataValueConforms(object, theDiagnostics, context);
     }
+    if (result || theDiagnostics != null)
+    {
+      result &= validate_UniqueID(object, theDiagnostics, context);
+    }
     return result;
   }
 
@@ -205,7 +211,7 @@ public class EObjectValidator implements EValidator
     }
     return result;
   }
-
+  
   protected boolean validate_MultiplicityConforms
     (EObject eObject, EStructuralFeature eStructuralFeature, DiagnosticChain diagnostics, Map context)
   {
@@ -226,7 +232,7 @@ public class EObjectValidator implements EValidator
                 (Diagnostic.ERROR,
                  DIAGNOSTIC_SOURCE,
                  EOBJECT__EVERY_MULTIPCITY_CONFORMS,
-                 EcorePlugin.INSTANCE.getString
+                 getEcoreResourceLocator().getString
                    ("_UI_FeatureHasTooFewValues_diagnostic",
                     new Object []
                       {
@@ -249,7 +255,7 @@ public class EObjectValidator implements EValidator
                 (Diagnostic.ERROR,
                  DIAGNOSTIC_SOURCE,
                  EOBJECT__EVERY_MULTIPCITY_CONFORMS,
-                 EcorePlugin.INSTANCE.getString
+                 getEcoreResourceLocator().getString
                    ("_UI_FeatureHasTooManyValues_diagnostic",
                     new Object []
                       {
@@ -278,7 +284,7 @@ public class EObjectValidator implements EValidator
                   (Diagnostic.ERROR,
                    DIAGNOSTIC_SOURCE,
                    EOBJECT__EVERY_MULTIPCITY_CONFORMS,
-                   EcorePlugin.INSTANCE.getString
+                   getEcoreResourceLocator().getString
                      ("_UI_FeatureHasTooManyValues_diagnostic",
                       new Object []
                         {
@@ -295,7 +301,7 @@ public class EObjectValidator implements EValidator
     }
     else if (eStructuralFeature.isRequired())
     {
-      if (!eObject.eIsSet(eStructuralFeature))
+      if (eStructuralFeature.isUnsettable() ? !eObject.eIsSet(eStructuralFeature) : eObject.eGet(eStructuralFeature, false) == null)
       {
         result = false;
         if (diagnostics != null)
@@ -305,7 +311,7 @@ public class EObjectValidator implements EValidator
               (Diagnostic.ERROR,
                DIAGNOSTIC_SOURCE,
                EOBJECT__EVERY_MULTIPCITY_CONFORMS,
-               EcorePlugin.INSTANCE.getString
+               getEcoreResourceLocator().getString
                  ("_UI_RequiredFeatureMustBeSet_diagnostic",
                   new Object [] { getFeatureLabel(eStructuralFeature, context), getObjectLabel(eObject, context) }),
                new Object [] { eObject, eStructuralFeature }));
@@ -332,7 +338,7 @@ public class EObjectValidator implements EValidator
               (Diagnostic.ERROR,
                DIAGNOSTIC_SOURCE,
                EOBJECT__EVERY_PROXY_RESOLVES,
-               EcorePlugin.INSTANCE.getString
+               getEcoreResourceLocator().getString
                  ("_UI_UnresolvedProxy_diagnostic",
                   new Object []
                     {
@@ -367,7 +373,7 @@ public class EObjectValidator implements EValidator
               (Diagnostic.ERROR,
                DIAGNOSTIC_SOURCE,
                EOBJECT__EVERY_REFERENCE_IS_CONTAINED,
-               EcorePlugin.INSTANCE.getString
+               getEcoreResourceLocator().getString
                  ("_UI_DanglingReference_diagnostic",
                   new Object []
                     {
@@ -484,7 +490,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          EOBJECT__EVERY_DATA_VALUE_CONFORMS,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_BadDataValue_diagnostic",
             new Object []
               {
@@ -886,7 +892,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__VALUE_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            (isInclusive ? "_UI_MinInclusiveConstraint_diagnostic" : "_UI_MinExclusiveConstraint_diagnostic",
             new Object []
               {
@@ -905,7 +911,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__VALUE_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            (isInclusive ? "_UI_MaxInclusiveConstraint_diagnostic" : "_UI_MaxExclusiveConstraint_diagnostic",
             new Object []
               {
@@ -924,7 +930,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__LENGTH_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_MinLengthConstraint_diagnostic",
             new Object []
               {
@@ -943,7 +949,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__LENGTH_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_MaxLengthConstraint_diagnostic",
             new Object []
               {
@@ -962,7 +968,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__TOTAL_DIGITS_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_TotalDigitsConstraint_diagnostic",
             new Object []
               {
@@ -980,7 +986,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__TOTAL_DIGITS_IN_RANGE,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_FractionDigitsConstraint_diagnostic",
             new Object []
               {
@@ -998,11 +1004,11 @@ public class EObjectValidator implements EValidator
     if (i.hasNext())
     {
       valueLiterals =
-        EcorePlugin.INSTANCE.getString("_UI_ListHead_composition", new Object [] { getValueLabel(eDataType, i.next(), context) });
+        getEcoreResourceLocator().getString("_UI_ListHead_composition", new Object [] { getValueLabel(eDataType, i.next(), context) });
       while (i.hasNext())
       {
         valueLiterals =
-          EcorePlugin.INSTANCE.getString
+          getEcoreResourceLocator().getString
             ("_UI_ListTail_composition",
              new Object [] { valueLiterals, getValueLabel(eDataType, i.next(), context) });
       }
@@ -1012,7 +1018,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__VALUE_IN_ENUMERATION,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_EnumerationConstraint_diagnostic",
             new Object []
               {
@@ -1028,10 +1034,10 @@ public class EObjectValidator implements EValidator
     String patternLiterals = "";
     if (patterns.length > 0)
     {
-      patternLiterals = EcorePlugin.INSTANCE.getString("_UI_ListHead_composition", new Object [] { patterns[0] });
+      patternLiterals = getEcoreResourceLocator().getString("_UI_ListHead_composition", new Object [] { patterns[0] });
       for (int i = 1; i < patterns.length; ++i)
       {
-        patternLiterals = EcorePlugin.INSTANCE.getString("_UI_ListTail_composition", new Object [] { patternLiterals, patterns[i] });
+        patternLiterals = getEcoreResourceLocator().getString("_UI_ListTail_composition", new Object [] { patternLiterals, patterns[i] });
       }
     }
 
@@ -1040,7 +1046,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__MATCHES_PATTERN,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_PatternConstraint_diagnostic",
             new Object []
               {
@@ -1058,7 +1064,7 @@ public class EObjectValidator implements EValidator
         (Diagnostic.ERROR,
          DIAGNOSTIC_SOURCE,
          DATA_VALUE__TYPE_CORRECT,
-         EcorePlugin.INSTANCE.getString
+         getEcoreResourceLocator().getString
            ("_UI_BadDataValueType_diagnostic",
             new Object []
               {
@@ -1073,4 +1079,48 @@ public class EObjectValidator implements EValidator
   {
     return java.util.Arrays.asList(values);
   }
+  
+  /**
+   * @since 2.2
+   */
+  public boolean validate_UniqueID(EObject eObject, DiagnosticChain diagnostics, Map context)
+  {
+    boolean result = true;
+    String id = EcoreUtil.getID(eObject);
+    if (id != null)
+    {
+      Resource resource = eObject.eResource();
+      if (resource != null)
+      {
+        EObject otherEObject = resource.getEObject(id);
+        if (eObject != otherEObject && otherEObject != null)
+        {
+          // ...
+          diagnostics.add
+            (new BasicDiagnostic
+              (Diagnostic.ERROR,
+               DIAGNOSTIC_SOURCE,
+               EOBJECT__UNIQUE_ID,
+               getEcoreResourceLocator().getString
+                 ("_UI_DuplicateID_diagnostic",
+                  new Object []
+                    {
+                      id,
+                      getObjectLabel(eObject, context),
+                      getObjectLabel(otherEObject, context)
+                    }),
+               new Object [] { eObject, otherEObject, id }));
+        }
+      }
+    }
+    return result;
+  }
+  
+  /**
+   * @since 2.2
+   */
+  protected ResourceLocator getEcoreResourceLocator()
+  {
+    return EcorePlugin.INSTANCE;
+  }
 }
