@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2005 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EcoreEList.java,v 1.6 2005/06/08 06:20:10 nickb Exp $
+ * $Id: EcoreEList.java,v 1.9.2.1 2007/03/29 14:36:10 emerks Exp $
  */
 package org.eclipse.emf.ecore.util;
 
@@ -57,13 +57,18 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
   protected Object validate(int index, Object object)
   {
     super.validate(index, object);
-    if (!hasInstanceClass() && object != null && !getFeatureType().isInstance(object))
+    if (!hasInstanceClass() && object != null && !isInstance(object))
     {
       throw new ArrayStoreException();
     }
     return object;
   }
 
+  protected boolean isInstance(Object object)
+  {
+    return dataClass.isInstance(object);
+  }
+
   public Object getNotifier()
   {
     return owner;
@@ -76,7 +81,7 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
 
   public int getFeatureID()
   {
-    return getEStructuralFeature().getFeatureID();
+    return owner.eClass().getFeatureID(getEStructuralFeature());
   }
 
   public EStructuralFeature getEStructuralFeature()
@@ -151,6 +156,19 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
       assign(index, validate(index, resolved));
       didSet(index, resolved, oldObject);
 
+      if (isContainment())
+      {
+        NotificationChain notificationChain = inverseRemove(eObject, null);
+        if (((InternalEObject)resolved).eInternalContainer() == null)
+        {
+          notificationChain = inverseAdd(resolved, notificationChain);
+        }
+        if (notificationChain != null)
+        {
+          notificationChain.dispatch();
+        }
+      }
+      
       if (isNotificationRequired())
       {
         owner.eNotify(createNotification(Notification.RESOLVE, eObject, resolved, index, false));
@@ -164,6 +182,11 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
     }
   }
 
+  protected Object resolve(Object object)
+  {
+    return isEObject() ? resolveProxy((EObject)object) : object;
+  }
+
   protected EObject resolveProxy(EObject eObject)
   {
     return eObject.eIsProxy() ? owner.eResolveProxy((InternalEObject)eObject) : eObject;
@@ -300,21 +323,36 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
     {
       if (size > 4)
       {
-        if (isContainment())
+        if (!isInstance(object))
+        {
+          return false;
+        }
+        else if (isContainment())
         {
-          if (!(object instanceof EObject)) return false;
           InternalEObject eObject = (InternalEObject)object;
-          return 
-            eObject.eContainer() == owner && 
+          boolean result = 
+            eObject.eInternalContainer() == owner && 
               (hasNavigableInverse() ? 
                  eObject.eBaseStructuralFeatureID(eObject.eContainerFeatureID(), dataClass) == getInverseFeatureID() :
                  InternalEObject.EOPPOSITE_FEATURE_BASE - eObject.eContainerFeatureID() == getFeatureID());
+          if (hasProxies() && !result)
+          {
+            for (int i = 0; i < size; ++i)
+            {
+              EObject containedEObject = resolveProxy((EObject)data[i]);
+              if (containedEObject == object)
+              {
+                return true;
+              }
+            }
+          }
+          return result;
         }
         // We can also optimize single valued reverse. 
         //
         else if (hasNavigableInverse() && !hasManyInverse())
         {
-          return object instanceof EObject && ((EObject)object).eGet(getInverseEReference()) == owner;
+          return ((EObject)object).eGet(getInverseEReference()) == owner;
         }
       }
 
@@ -667,6 +705,11 @@ public class EcoreEList extends NotifyingListImpl implements InternalEList.Unset
       return (kind & HAS_INSTANCE_CLASS) != 0;
     }
 
+    protected boolean isInstance(Object object)
+    {
+      return dataClass == null ? getFeatureType().isInstance(object) : super.isInstance(object);
+    }
+
     protected boolean isContainer()
     {
       return (kind & IS_CONTAINER) != 0;
