@@ -3,16 +3,16 @@
  *
  * Copyright (c) 2002-2004 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Common Public License v1.0
+ * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/cpl-v10.html
+ * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
  *
  * </copyright>
  *
- * $Id: EcoreResourceFactoryImpl.java,v 1.3 2004/05/06 18:41:08 emerks Exp $
+ * $Id: EcoreResourceFactoryImpl.java,v 1.5 2006/05/10 17:31:52 emerks Exp $
  */
 package org.eclipse.emf.ecore.xmi.impl;
 
@@ -35,7 +35,14 @@ public class EcoreResourceFactoryImpl extends ResourceFactoryImpl
 
   public Resource createResource(URI uri)
   {
-    XMLResourceImpl result = new XMIResourceImpl(uri);
+    XMLResource result = 
+      new XMIResourceImpl(uri)
+      {
+        protected boolean useIDs()
+        {
+          return eObjectToIDMap != null || idToEObjectMap != null;
+        }
+      };
     result.setEncoding("UTF-8");
 
     result.getDefaultSaveOptions().put(XMLResource.OPTION_USE_ENCODED_ATTRIBUTE_STYLE, Boolean.TRUE);
