@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XMISaveImpl.java,v 1.9 2005/06/08 06:16:07 nickb Exp $
+ * $Id: XMISaveImpl.java,v 1.13 2006/04/26 12:32:50 emerks Exp $
  */
 package org.eclipse.emf.ecore.xmi.impl;
 
@@ -33,6 +33,7 @@ import org.w3c.dom.Element;
 public class XMISaveImpl extends XMLSaveImpl
 {
   protected boolean xmiType;
+  protected String xmiURI = XMIResource.XMI_URI;
 
   protected static final String XMI_ID_NS = XMIResource.XMI_NS + ":" + XMIResource.XMI_ID; // xmi:id
   protected static final String XMI_TAG_NS = XMIResource.XMI_NS + ":" + XMIResource.XMI_TAG_NAME; // xmi:XMI
@@ -49,7 +50,12 @@ public class XMISaveImpl extends XMLSaveImpl
 
   public XMISaveImpl(Map options, XMLHelper helper, String encoding)
   {
-    super(options, helper, encoding);
+    this(options, helper, encoding, "1.0");
+  }
+
+  public XMISaveImpl(Map options, XMLHelper helper, String encoding, String xmlVersion)
+  {
+    super(options, helper, encoding, xmlVersion);
     this.xmiType = Boolean.TRUE.equals(options.get(XMIResource.OPTION_USE_XMI_TYPE));
     idAttributeName = XMI_ID_NS;
     idAttributeNS = XMIResource.XMI_NS;
@@ -59,7 +65,8 @@ public class XMISaveImpl extends XMLSaveImpl
   {
     super.init(resource, options);
     this.xmiType = Boolean.TRUE.equals(options.get(XMIResource.OPTION_USE_XMI_TYPE));
-    helper.getPrefixToNamespaceMap().put(XMIResource.XMI_NS, XMIResource.XMI_URI);
+    xmiURI = xmlResource == null ? XMIResource.XMI_URI : ((XMIResource)xmlResource).getXMINamespace();
+    helper.getPrefixToNamespaceMap().put(XMIResource.XMI_NS, xmiURI);
   }
 
   public Object writeTopObjects(List contents)
@@ -75,6 +82,7 @@ public class XMISaveImpl extends XMLSaveImpl
         EClass eClass = top.eClass();
         String name = helper.getQName(eClass);
         doc.startElement(name);
+        root = top;
         saveElementID(top);
       }
 
@@ -93,6 +101,7 @@ public class XMISaveImpl extends XMLSaveImpl
         helper.populateNameInfo(nameInfo, eClass);
         currentNode = currentNode.appendChild(document.createElementNS(nameInfo.getNamespaceURI(), nameInfo.getQualifiedName()));
         handler.recordValues(currentNode, null, null, top);
+        root = top;
         saveElementID(top);
       }
       return null;
@@ -120,22 +129,27 @@ public class XMISaveImpl extends XMLSaveImpl
 
   public void addNamespaceDeclarations()
   {
+    String version = XMIResource.VERSION_VALUE;
+    if (xmlResource != null)
+    {
+      version = ((XMIResource)xmlResource).getXMIVersion();
+    }
     if (!toDOM)
     {
-      doc.addAttribute(XMI_VER_NS, XMIResource.VERSION_VALUE);
-      doc.addAttribute(XMI_XMLNS, XMIResource.XMI_URI);
+        doc.addAttribute(XMI_VER_NS, version);
+        doc.addAttribute(XMI_XMLNS, xmiURI);         
     }
     else
     {
-      ((Element)currentNode).setAttributeNS(XMIResource.XMI_URI, XMI_VER_NS, XMIResource.VERSION_VALUE);
-      ((Element)currentNode).setAttributeNS(ExtendedMetaData.XMLNS_URI, XMI_XMLNS, XMIResource.XMI_URI);
+      ((Element)currentNode).setAttributeNS(XMIResource.XMI_URI, XMI_VER_NS, version);
+      ((Element)currentNode).setAttributeNS(ExtendedMetaData.XMLNS_URI, XMI_XMLNS, xmiURI);
     }
     super.addNamespaceDeclarations();
   }
 
   public boolean isDuplicateURI(String nsURI)
   {
-    return XMIResource.XMI_URI.equals(nsURI);
+    return xmiURI.equals(nsURI);
   }
 
   protected void saveFeatureMapElementReference(EObject o, EReference f)
