@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XMLLoadImpl.java,v 1.19 2006/05/04 11:49:45 emerks Exp $
+ * $Id: XMLLoadImpl.java,v 1.19.2.2 2007/02/20 12:06:54 emerks Exp $
  */
 package org.eclipse.emf.ecore.xmi.impl;
 
@@ -65,6 +65,9 @@ public class XMLLoadImpl implements XMLLoad
   protected XMLHelper helper;
   protected Map options;
 
+  // This will be made protected in 2.3.0
+  private boolean namespaceAware;
+
   public XMLLoadImpl(XMLHelper helper)
   {
     this.helper = helper;
@@ -119,9 +122,10 @@ public class XMLLoadImpl implements XMLLoad
     parserProperties = (parserProperties == null) ? Collections.EMPTY_MAP : parserProperties;
 
     // HACK: reading encoding
+    String encoding = null;
     if (!Boolean.FALSE.equals(options.get(XMLResource.OPTION_USE_DEPRECATED_METHODS)))
     {
-      String encoding = getEncoding();
+      encoding = getEncoding();
       resource.setEncoding(encoding);
     }
     try
@@ -164,7 +168,7 @@ public class XMLLoadImpl implements XMLLoad
         String resourceURI = resource.getURI().toString();
         inputSource.setPublicId(resourceURI);
         inputSource.setSystemId(resourceURI);
-        inputSource.setEncoding(resource.getEncoding());
+        inputSource.setEncoding(encoding);
       }
     
       // set lexical handler
@@ -365,6 +369,7 @@ public class XMLLoadImpl implements XMLLoad
   {
     this.resource = resource;
     this.options = options;
+    this.namespaceAware = !Boolean.FALSE.equals(XMLResource.OPTION_USE_DEPRECATED_METHODS);
     DefaultHandler handler;
     XMLParserPool pool = (XMLParserPool)options.get(XMLResource.OPTION_USE_PARSER_POOL);
     if (pool != null)
@@ -438,12 +443,20 @@ public class XMLLoadImpl implements XMLLoad
       {
         Node attr = attributes.item(i);
         String namespaceURI = attr.getNamespaceURI();
+        if (namespaceURI == null)
+        {
+          namespaceURI = "";
+        }
         if (ExtendedMetaData.XMLNS_URI.equals(namespaceURI))
         {
           // add non-duplicate namespace declaration
           if (attrs.getIndex(attr.getNodeName()) < 0)
           {
             attrs.addAttribute("", "", attr.getNodeName(), "CDATA", attr.getNodeValue());
+            if (namespaceAware)
+            {
+              handler.startPrefixMapping(attr.getLocalName(), attr.getNodeValue());
+            }
           }
         }
         else
@@ -467,6 +480,10 @@ public class XMLLoadImpl implements XMLLoad
           if (ExtendedMetaData.XMLNS_URI.equals(attr.getNamespaceURI()) && attrs.getIndex(attr.getNodeName()) < 0)
           {          
             attrs.addAttribute("", "", attr.getNodeName(), "CDATA", attr.getNodeValue());
+            if (namespaceAware)
+            {
+              handler.startPrefixMapping(attr.getLocalName(), attr.getNodeValue());
+            }
           }
         }
       }
@@ -475,6 +492,10 @@ public class XMLLoadImpl implements XMLLoad
 
     // traverse element node
     String namespaceURI = element.getNamespaceURI();
+    if (namespaceURI == null)
+    {
+      namespaceURI = "";
+    }
     String localName = element.getLocalName();
     String qname = element.getNodeName();   
     
@@ -521,7 +542,24 @@ public class XMLLoadImpl implements XMLLoad
       case Node.ELEMENT_NODE:
       {
         attributesProxy.setAttributes(node.getAttributes());
+        if (namespaceAware)
+        {
+          NamedNodeMap attributes = node.getAttributes();
+          for (int i = 0; i < attributes.getLength(); i++)
+          {
+            Node attr = attributes.item(i);
+            String namespaceURI = attr.getNamespaceURI();
+            if (ExtendedMetaData.XMLNS_URI.equals(namespaceURI))
+            {
+              handler.startPrefixMapping(attr.getLocalName(), attr.getNodeValue());
+            }
+          }
+        }
         String namespaceURI = node.getNamespaceURI();
+        if (namespaceURI == null)
+        {
+          namespaceURI = "";
+        }
         String localName = node.getLocalName();
         String qname = node.getNodeName();   
         
