@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2005 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XMLResourceImpl.java,v 1.9 2005/06/15 21:16:49 elena Exp $
+ * $Id: XMLResourceImpl.java,v 1.19 2006/04/26 12:36:10 emerks Exp $
  */
 package org.eclipse.emf.ecore.xmi.impl;
 
@@ -20,6 +20,7 @@ package org.eclipse.emf.ecore.xmi.impl;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.io.Writer;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -29,6 +30,7 @@ import java.util.WeakHashMap;
 
 import javax.xml.parsers.DocumentBuilderFactory;
 
+import org.eclipse.emf.common.notify.Notification;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.resource.impl.ResourceImpl;
@@ -41,6 +43,7 @@ import org.eclipse.emf.ecore.xmi.XMLResource;
 import org.eclipse.emf.ecore.xmi.XMLSave;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
+import org.xml.sax.InputSource;
 
 
 /**
@@ -67,6 +70,7 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
   protected Map eObjectToExtensionMap;
 
   protected String encoding;
+  protected String xmlVersion;
   protected boolean useZip;
   protected String publicId;
   protected String systemId;
@@ -100,11 +104,12 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
   protected void init()
   {
     encoding = "ASCII";
+    xmlVersion = "1.0";
   }
 
   protected boolean useIDs()
   {
-    return true;
+    return eObjectToIDMap != null || idToEObjectMap != null || useUUIDs();
   }
 
   protected boolean useIDAttributes()
@@ -117,6 +122,11 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
     return false;
   }
 
+  protected boolean assignIDsWhileLoading()
+  {
+    return true;
+  }
+
   public Map getDefaultSaveOptions()
   {
     if (defaultSaveOptions == null)
@@ -198,6 +208,48 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
       handler.postSave(this, outputStream, options);
     }
   }
+  
+  /**
+   * Saves the resource to the writer using the specified options.
+   * <p>
+   * This implementation is <code>final</code>;
+   * clients should override {@link #doSave doSave}.
+   * </p>
+   * @param writer the writer
+   * @param options the save options.
+   * @see #doSave(Writer, Map)
+   */
+  public final void save(Writer writer, Map options) throws IOException
+  {   
+    if (defaultSaveOptions == null || defaultSaveOptions.isEmpty())
+    {
+      doSave(writer, options);
+    }
+    else if (options == null)
+    {
+      doSave(writer, defaultSaveOptions);
+    }
+    else
+    {
+      Map mergedOptions = new HashMap(defaultSaveOptions);
+      mergedOptions.putAll(options);
+      doSave(writer, mergedOptions);
+    }
+
+    setModified(false);
+  }
+  
+  public void doSave(Writer writer, Map options) throws IOException
+  {
+    XMLSave xmlSave = createXMLSave();
+
+    if (options == null)
+    {
+      options = Collections.EMPTY_MAP;
+    }
+
+    xmlSave.save(this, writer, options);
+  }
 
   public Document save(Document doc, Map options, DOMHandler handler)
   {
@@ -221,7 +273,7 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
     }
     if (defaultSaveOptions == null || defaultSaveOptions.isEmpty())
     {
-      return xmlSave.save(this, document, options, domHandler);
+      return xmlSave.save(this, document, options == null ? Collections.EMPTY_MAP : options, domHandler);
     }
     else if (options == null)
     {
@@ -234,7 +286,7 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
       return xmlSave.save(this, document, mergedOptions, domHandler);
     }
   }
-
+  
   public DOMHelper getDOMHelper()
   {
     return domHandler.getDOMHelper();
@@ -273,6 +325,16 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
   {
     this.encoding = encoding;
   }
+  
+  public String getXMLVersion()
+  {
+    return xmlVersion;
+  }
+
+  public void setXMLVersion(String version)
+  {
+    this.xmlVersion = version;
+  }
 
   public Map getIDToEObjectMap()
   {
@@ -390,12 +452,15 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
       String id = getID(eObject);
       if (useUUIDs() && id == null)
       {
-        id = (String)DETACHED_EOBJECT_TO_ID_MAP.remove(eObject);
-        if (id == null)
+        if (assignIDsWhileLoading() || !isLoading())
         {
-          id = EcoreUtil.generateUUID();
+          id = (String)DETACHED_EOBJECT_TO_ID_MAP.remove(eObject);
+          if (id == null)
+          {
+            id = EcoreUtil.generateUUID();
+          }
+          setID(eObject, id);
         }
-        setID(eObject, id);
       }
       else if (id != null)
       {
@@ -476,11 +541,60 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
     }
     return result.toString();
   }
+  
+  public final void load(Node node, Map options) throws IOException
+  {
+    if (!isLoaded)
+    {
+      Notification notification = setLoaded(true);
+      isLoading = true;
+
+      if (errors != null)
+      {
+        errors.clear();
+      }
+
+      if (warnings != null)
+      {
+        warnings.clear();
+      }
+
+      try
+      {
+        if (defaultLoadOptions == null || defaultLoadOptions.isEmpty())
+        {
+          doLoad(node, options);
+        }
+        else if (options == null)
+        {
+          doLoad(node, defaultLoadOptions);
+        }
+        else
+        {
+          Map mergedOptions = new HashMap(defaultLoadOptions);
+          mergedOptions.putAll(options);
+  
+          doLoad(node, mergedOptions);
+        }
+      }
+      finally
+      {
+        isLoading = false;
+
+        if (notification != null)
+        {
+          eNotify(notification);
+        }
+  
+        setModified(false);
+      } 
+    }
+  }
 
   /* (non-Javadoc)
    * @see org.eclipse.emf.ecore.xmi.XMLResource#load(org.w3c.dom.Node, java.util.Map)
    */
-  public void load(Node node, Map options) throws IOException
+  public void doLoad(Node node, Map options) throws IOException
   {
     XMLLoad xmlLoad = createXMLLoad();
 
@@ -489,22 +603,66 @@ public class XMLResourceImpl extends ResourceImpl implements XMLResource
       options = Collections.EMPTY_MAP;
     }
     
-    if (defaultLoadOptions == null || defaultLoadOptions.isEmpty())
+    xmlLoad.load(this, node, options); 
+  }
+  
+  public final void load(InputSource inputSource, Map options) throws IOException
+  {
+    if (!isLoaded)
     {
-      xmlLoad.load(this, node, options);
-    }
-    else if (options == null)
-    {
-      xmlLoad.load(this, node, defaultLoadOptions);
-    }
-    else
-    {
-      Map mergedOptions = new HashMap(defaultLoadOptions);
-      mergedOptions.putAll(options);
+      Notification notification = setLoaded(true);
+      isLoading = true;
 
-      xmlLoad.load(this, node, mergedOptions);
-    }
+      if (errors != null)
+      {
+        errors.clear();
+      }
 
-    
+      if (warnings != null)
+      {
+        warnings.clear();
+      }
+
+      try
+      {
+        if (defaultLoadOptions == null || defaultLoadOptions.isEmpty())
+        {
+          doLoad(inputSource, options);
+        }
+        else if (options == null)
+        {
+          doLoad(inputSource, defaultLoadOptions);
+        }
+        else
+        {
+          Map mergedOptions = new HashMap(defaultLoadOptions);
+          mergedOptions.putAll(options);
+  
+          doLoad(inputSource, mergedOptions);
+        }
+      }
+      finally
+      {
+        isLoading = false;
+
+        if (notification != null)
+        {
+          eNotify(notification);
+        }
+  
+        setModified(false);
+      } 
+    }
+  }
+  
+  public void doLoad(InputSource inputSource, Map options) throws IOException
+  {
+    XMLLoad xmlLoad = createXMLLoad();
+
+    if (options == null)
+    {
+      options = Collections.EMPTY_MAP;
+    }
+    xmlLoad.load(this, inputSource, options);
   }
 }
