@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: DragAndDropCommand.java,v 1.6 2005/06/08 06:17:05 nickb Exp $
+ * $Id: DragAndDropCommand.java,v 1.8 2006/05/30 11:40:51 emerks Exp $
  */
 package org.eclipse.emf.edit.command;
 
@@ -269,11 +269,11 @@ public class DragAndDropCommand extends AbstractCommand implements DragAndDropFe
           if (location <= 0.20)
           {
             lowerLocationBound = 0.0F;
-            upperLocationBound = 2.0F;
+            upperLocationBound = 0.2F;
           }
           else 
           {
-            lowerLocationBound = 8.0F;
+            lowerLocationBound = 0.8F;
             upperLocationBound = 1.0F;
           }
         }
@@ -806,10 +806,15 @@ public class DragAndDropCommand extends AbstractCommand implements DragAndDropFe
       dropCommand = SetCommand.create(domain, owner, null, collection.iterator().next());
     }
 
-    if (!dropCommand.canExecute() || analyzeForNonContainment(dropCommand))
+    if (!dropCommand.canExecute() || !analyzeForNonContainment(dropCommand))
     {
       dropCommand.dispose();
       dropCommand = AddCommand.create(domain, owner, null, collection);
+      if (!analyzeForNonContainment(dropCommand))
+      {
+        dropCommand.dispose();
+        dropCommand = UnexecutableCommand.INSTANCE;
+      }
     }
 
     boolean result = dropCommand.canExecute();
