@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,17 +12,20 @@
  *
  * </copyright>
  *
- * $Id: FeatureEditorDialog.java,v 1.7 2005/06/08 06:20:52 nickb Exp $
+ * $Id: FeatureEditorDialog.java,v 1.9 2006/05/26 20:02:46 marcelop Exp $
  */
 package org.eclipse.emf.edit.ui.celleditor;
 
 
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.jface.dialogs.Dialog;
+import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IContentProvider;
+import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.StructuredSelection;
@@ -45,6 +48,7 @@ import org.eclipse.swt.widgets.Text;
 
 import org.eclipse.emf.common.notify.AdapterFactory;
 import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;
+import org.eclipse.emf.common.ui.celleditor.ExtendedComboBoxCellEditor;
 import org.eclipse.emf.common.util.BasicEList;
 import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.ecore.EClassifier;
@@ -68,6 +72,37 @@ public class FeatureEditorDialog extends Dialog
   protected ItemProvider values;
   protected List choiceOfValues;
   protected EList result;
+  protected boolean multiLine;
+
+  public FeatureEditorDialog
+    (Shell parent, 
+     ILabelProvider labelProvider, 
+     Object object, 
+     EClassifier eClassifier, 
+     List currentValues, 
+     String displayName, 
+     List choiceOfValues,
+     boolean multiLine,
+     boolean sortChoices)
+  {
+    super(parent);
+    setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
+    this.labelProvider = labelProvider;
+    this.object = object;
+    this.eClassifier = eClassifier;
+    this.displayName = displayName;
+    this.choiceOfValues = choiceOfValues;
+    this.multiLine = multiLine;
+
+    AdapterFactory adapterFactory = new ComposedAdapterFactory(Collections.EMPTY_LIST);
+    values = new ItemProvider(adapterFactory, currentValues);
+    contentProvider = new AdapterFactoryContentProvider(adapterFactory);
+    if (sortChoices && choiceOfValues != null)
+    {
+      this.choiceOfValues = new ArrayList(choiceOfValues);
+      ExtendedComboBoxCellEditor.createItems(this.choiceOfValues, labelProvider, true);
+    }
+  }
 
   public FeatureEditorDialog
     (Shell parent, 
@@ -78,17 +113,7 @@ public class FeatureEditorDialog extends Dialog
      String displayName, 
      List choiceOfValues)
   {
-    super(parent);
-    setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
-    this.labelProvider = labelProvider;
-    this.object = object;
-    this.eClassifier = eClassifier;
-    this.displayName = displayName;
-    this.choiceOfValues = choiceOfValues;
-
-    AdapterFactory adapterFactory = new ComposedAdapterFactory(Collections.EMPTY_LIST);
-    values = new ItemProvider(adapterFactory, currentValues);
-    contentProvider = new AdapterFactoryContentProvider(adapterFactory);
+    this(parent, labelProvider, object, eClassifier, currentValues, displayName, choiceOfValues, false, false);
   }
 
   public FeatureEditorDialog
@@ -173,14 +198,24 @@ public class FeatureEditorDialog extends Dialog
       choiceTableViewer.setInput(new ItemProvider(choiceOfValues));
     }
 
-    final Text choiceText = choiceOfValues == null ? new Text(choiceComposite, SWT.MULTI | SWT.BORDER) : null;
+    // We use multi even for a single line because we want to respond to the enter key.
+    //
+    int style = multiLine ?
+      SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER :
+      SWT.MULTI | SWT.BORDER;
+    final Text choiceText = choiceOfValues == null ? new Text(choiceComposite, style) : null;
     if (choiceText != null)
     {
       GridData choiceTextGridData = new GridData();
       choiceTextGridData.widthHint = Display.getCurrent().getBounds().width / 5;
       choiceTextGridData.verticalAlignment = SWT.BEGINNING;
       choiceTextGridData.horizontalAlignment = SWT.FILL;
-      choiceTextGridData.grabExcessHorizontalSpace= true;
+      choiceTextGridData.grabExcessHorizontalSpace = true;
+      if (multiLine)
+      {
+        choiceTextGridData.verticalAlignment = SWT.FILL;
+        choiceTextGridData.grabExcessVerticalSpace = true;
+      }
       choiceText.setLayoutData(choiceTextGridData);
     }
 
@@ -269,6 +304,31 @@ public class FeatureEditorDialog extends Dialog
       featureTableViewer.setSelection(new StructuredSelection(values.getChildren().get(0)));
     }
     
+    if (choiceTableViewer != null)
+    {
+      choiceTableViewer.addDoubleClickListener(new IDoubleClickListener()
+        {
+          public void doubleClick(DoubleClickEvent event)
+          {
+            if (addButton.isEnabled())
+            {
+              addButton.notifyListeners(SWT.Selection, null);
+            }
+          }
+        });
+
+      featureTableViewer.addDoubleClickListener(new IDoubleClickListener()
+      {
+        public void doubleClick(DoubleClickEvent event)
+        {
+          if (removeButton.isEnabled())
+          {
+            removeButton.notifyListeners(SWT.Selection, null);
+          }
+        }
+      });
+    }
+    
     if (choiceText != null)
     {
       choiceText.addKeyListener(
@@ -276,7 +336,7 @@ public class FeatureEditorDialog extends Dialog
         {
           public void keyPressed(KeyEvent event)
           {
-            if (event.character == '\r' || event.character == '\n')
+            if (!multiLine && (event.character == '\r' || event.character == '\n'))
             {
               try
               {
@@ -334,6 +394,7 @@ public class FeatureEditorDialog extends Dialog
     addButton.addSelectionListener(
       new SelectionAdapter()
       {
+        // event is null when choiceTableViewer is double clicked
         public void widgetSelected(SelectionEvent event)
         {
           if (choiceTableViewer != null)
@@ -368,6 +429,7 @@ public class FeatureEditorDialog extends Dialog
     removeButton.addSelectionListener(
       new SelectionAdapter()
       {
+        // event is null when featureTableViewer is double clicked 
         public void widgetSelected(SelectionEvent event)
         {
           IStructuredSelection selection = (IStructuredSelection)featureTableViewer.getSelection();
