@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: EcoreXMLSchemaBuilder.java,v 1.7 2005/06/08 06:23:01 nickb Exp $
+ * $Id: EcoreXMLSchemaBuilder.java,v 1.10 2005/11/24 19:46:14 elena Exp $
  */
 package org.eclipse.xsd.ecore;
 
@@ -95,6 +95,7 @@ public class EcoreXMLSchemaBuilder extends MapBuilder
   protected boolean useEncodedAttributeStyle;
   protected boolean enforceLowerBound;
   protected List rootClasses;
+  protected XSDParser xsdParser;
 
   public EcoreXMLSchemaBuilder()
   {
@@ -318,6 +319,10 @@ public class EcoreXMLSchemaBuilder extends MapBuilder
   {
     XSDComplexTypeDefinition xsdComplexTypeDefinition = XSDFactory.eINSTANCE.createXSDComplexTypeDefinition();
     xsdComplexTypeDefinition.setName(getName(eClass));
+    if (eClass.isAbstract())
+    {
+      xsdComplexTypeDefinition.setAbstract(true);
+    }
     List superClasses = eClass.getESuperTypes();
 
     if (superClasses.size() > 0)
@@ -820,7 +825,10 @@ public class EcoreXMLSchemaBuilder extends MapBuilder
 
           // Try to parse the documentation and use the parsed version if it's successful.
           //
-          XSDParser xsdParser = new XSDParser();
+          if (xsdParser == null)
+          {
+            xsdParser = new XSDParser(null);
+          }
           xsdParser.parseString("<documentation>" + documentation + "</documentation>");
           Document document = xsdParser.getDocument();
           if (xsdParser.getDiagnostics().isEmpty() && document.getDocumentElement().getFirstChild() != null)
