@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XSDAttributeGroupDefinitionImpl.java,v 1.11 2005/11/25 13:14:00 emerks Exp $
+ * $Id: XSDAttributeGroupDefinitionImpl.java,v 1.12.2.1 2007/05/08 19:12:32 emerks Exp $
  */
 package org.eclipse.xsd.impl;
 
@@ -243,7 +243,7 @@ public class XSDAttributeGroupDefinitionImpl
       XSDAttributeGroupDefinition newResolvedAttributeGroupDefinition =
         resolveAttributeGroupDefinition
           (theResolvedAttributeGroupDefinition.getTargetNamespace(), theResolvedAttributeGroupDefinition.getName());
-      if (newResolvedAttributeGroupDefinition.getContainer() != null)
+      if (forceResolve || newResolvedAttributeGroupDefinition.getContainer() != null)
       {
         handleNewResolvedAttributeGroupDefinition(newResolvedAttributeGroupDefinition);
       }
@@ -530,6 +530,14 @@ public class XSDAttributeGroupDefinitionImpl
     return localWildcard;
   }
 
+  protected void patchTargetNamespaceAttribute(XSDSchema xsdSchema)
+  {
+    if (!isAttributeGroupDefinitionReference())
+    {
+      super.patchTargetNamespaceAttribute(xsdSchema);
+    }
+  }
+
   protected void reconcileAttributes(Element changedElement)
   {
     super.reconcileAttributes(changedElement);
