@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XSDElementDeclarationImpl.java,v 1.15 2006/05/03 20:39:01 davidms Exp $
+ * $Id: XSDElementDeclarationImpl.java,v 1.16.2.3 2007/05/08 19:12:32 emerks Exp $
  */
 package org.eclipse.xsd.impl;
 
@@ -547,12 +547,12 @@ public class XSDElementDeclarationImpl
     if (theResolvedElementDeclaration == this)
     {
       XSDTypeDefinition typeDefinition = getTypeDefinition();
-      if (typeDefinition != null && (forceResolve || typeDefinition.getContainer() == null))
+      if (typeDefinition != null && (forceResolve && typeDefinition.getName() != null || typeDefinition.getContainer() == null))
       {
         XSDTypeDefinition newTypeDefinition = resolveTypeDefinition(typeDefinition.getTargetNamespace(), typeDefinition.getName());
-        if (newTypeDefinition.getContainer() != null && newTypeDefinition != typeDefinition)
+        if (forceResolve || newTypeDefinition.getContainer() != null && newTypeDefinition != typeDefinition)
         {
-          setTypeDefinition(newTypeDefinition);
+          setTypeDefinitionGen(newTypeDefinition);
         }
       }
 
@@ -724,29 +724,42 @@ public class XSDElementDeclarationImpl
       XSDSchema xsdSchema = getSchema();
       if (xsdSchema != null)
       {
-        if (getScope() instanceof XSDSchema)
-        {
-          if (!isSetForm() || XSDForm.QUALIFIED_LITERAL != getForm())
-          {
-            setForm(XSDForm.QUALIFIED_LITERAL);
-          }
-        }
+        patchTargetNamespaceAttributeHelper(xsdSchema);
+      }
+    }
+  }
 
-        if (isSetForm() ? XSDForm.UNQUALIFIED_LITERAL == getForm() : XSDForm.UNQUALIFIED_LITERAL == xsdSchema.getElementFormDefault())
-        {
-          if (getTargetNamespace() != null)
-          {
-            setTargetNamespace(null);
-          }
-        }
-        else 
-        {
-          String newTargetNamespace = xsdSchema.getTargetNamespace();
-          if (newTargetNamespace == null ? getTargetNamespace() != null : !newTargetNamespace.equals(getTargetNamespace()))
-          {
-            setTargetNamespace(newTargetNamespace);
-          }
-        }
+  protected void patchTargetNamespaceAttribute(XSDSchema xsdSchema)
+  {
+    if (!isElementDeclarationReference())
+    {
+      patchTargetNamespaceAttributeHelper(xsdSchema);
+    }
+  }
+
+  protected void patchTargetNamespaceAttributeHelper(XSDSchema xsdSchema)
+  {
+    if (getScope() instanceof XSDSchema)
+    {
+      if (!isSetForm() || XSDForm.QUALIFIED_LITERAL != getForm())
+      {
+        setForm(XSDForm.QUALIFIED_LITERAL);
+      }
+    }
+
+    if (isSetForm() ? XSDForm.UNQUALIFIED_LITERAL == getForm() : XSDForm.UNQUALIFIED_LITERAL == xsdSchema.getElementFormDefault())
+    {
+      if (getTargetNamespace() != null)
+      {
+        setTargetNamespace(null);
+      }
+    }
+    else 
+    {
+      String newTargetNamespace = xsdSchema.getTargetNamespace();
+      if (newTargetNamespace == null ? getTargetNamespace() != null : !newTargetNamespace.equals(getTargetNamespace()))
+      {
+        setTargetNamespace(newTargetNamespace);
       }
     }
   }
@@ -1077,6 +1090,7 @@ public class XSDElementDeclarationImpl
       {
         if (changedElement.hasAttributeNS(null, XSDConstants.TYPE_ATTRIBUTE))
         {
+          isTypeExplicit = true;
           XSDTypeDefinition newTypeDefinition =
             resolveTypeDefinitionURI(XSDConstants.lookupQNameForAttribute(changedElement, XSDConstants.TYPE_ATTRIBUTE));
           if (newTypeDefinition != getTypeDefinition())
@@ -1084,6 +1098,11 @@ public class XSDElementDeclarationImpl
             setTypeDefinition(newTypeDefinition);
           }
         }
+        else if (getAnonymousTypeDefinition() != getTypeDefinition())
+        {
+          isTypeExplicit = false;
+          setTypeDefinitionGen(resolveSimpleTypeDefinition(changedElement.getNamespaceURI(), "anyType"));
+        }
 
         if (changedElement.hasAttributeNS(null, XSDConstants.NILLABLE_ATTRIBUTE))
         {
@@ -1248,12 +1267,13 @@ public class XSDElementDeclarationImpl
 
       if (theElement.hasAttributeNS(null, XSDConstants.TYPE_ATTRIBUTE))
       {
+        isTypeExplicit = true;
         newTypeDefinition = resolveTypeDefinitionURI(XSDConstants.lookupQNameForAttribute(theElement, XSDConstants.TYPE_ATTRIBUTE));
       }
 
       if (newTypeDefinition != null && newTypeDefinition != getTypeDefinition())
       {
-        setTypeDefinition(newTypeDefinition);
+        setTypeDefinitionGen(newTypeDefinition);
       }
     }
   }
@@ -1410,10 +1430,9 @@ public class XSDElementDeclarationImpl
         XSDTypeDefinition theTypeDefinition = getTypeDefinition();
         XSDTypeDefinition theAnonymousTypeDefinition = getAnonymousTypeDefinition();
 
-        if (theTypeDefinition == null ||
-              theTypeDefinition == theAnonymousTypeDefinition ||
-              XSDConstants.isURType(theTypeDefinition) || 
-              !isTypeExplicit)
+        if (!isTypeExplicit ||
+              theTypeDefinition == null ||
+              theTypeDefinition == theAnonymousTypeDefinition)
         {
           if (theElement != null)
           {
