@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XSDIdentityConstraintDefinitionItemProvider.java,v 1.4 2005/06/12 12:34:45 emerks Exp $
+ * $Id: XSDIdentityConstraintDefinitionItemProvider.java,v 1.5 2006/01/25 00:27:41 emerks Exp $
  */
 package org.eclipse.xsd.provider;
 
@@ -70,8 +70,8 @@ public class XSDIdentityConstraintDefinitionItemProvider
       itemPropertyDescriptors.add
         (new ItemPropertyDescriptor
           (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
-           XSDEditPlugin.getString("_UI_IdentityConstraintCategory_label"),
-           XSDEditPlugin.getString("_UI_IdentityConstraintCategory_description"),
+           XSDEditPlugin.INSTANCE.getString("_UI_IdentityConstraintCategory_label"),
+           XSDEditPlugin.INSTANCE.getString("_UI_IdentityConstraintCategory_description"),
            xsdPackage.getXSDIdentityConstraintDefinition_IdentityConstraintCategory(),
            true,
            ItemPropertyDescriptor.TEXT_VALUE_IMAGE));
@@ -82,8 +82,8 @@ public class XSDIdentityConstraintDefinitionItemProvider
       itemPropertyDescriptors.add
         (new ItemPropertyDescriptor
           (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
-           XSDEditPlugin.getString("_UI_Selector_label"),
-           XSDEditPlugin.getString("_UI_Selector_description"),
+           XSDEditPlugin.INSTANCE.getString("_UI_Selector_label"),
+           XSDEditPlugin.INSTANCE.getString("_UI_Selector_description"),
            xsdPackage.getXSDIdentityConstraintDefinition_Selector(),
            true,
            ItemPropertyDescriptor.TEXT_VALUE_IMAGE));
@@ -94,8 +94,8 @@ public class XSDIdentityConstraintDefinitionItemProvider
       itemPropertyDescriptors.add
         (new ItemPropertyDescriptor
           (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
-           XSDEditPlugin.getString("_UI_ReferencedKey_label"),
-           XSDEditPlugin.getString("_UI_ReferencedKey_description"),
+           XSDEditPlugin.INSTANCE.getString("_UI_ReferencedKey_label"),
+           XSDEditPlugin.INSTANCE.getString("_UI_ReferencedKey_description"),
            xsdPackage.getXSDIdentityConstraintDefinition_ReferencedKey(), 
            false));
 
@@ -104,8 +104,8 @@ public class XSDIdentityConstraintDefinitionItemProvider
       itemPropertyDescriptors.add
         (new ItemPropertyDescriptor
           (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
-           XSDEditPlugin.getString("_UI_Annotation_label"),
-           XSDEditPlugin.getString("_UI_AnnotationOfIdentityConstraint_description"),
+           XSDEditPlugin.INSTANCE.getString("_UI_Annotation_label"),
+           XSDEditPlugin.INSTANCE.getString("_UI_AnnotationOfIdentityConstraint_description"),
            xsdPackage.getXSDIdentityConstraintDefinition_Annotation(), 
            false));
 
@@ -137,7 +137,7 @@ public class XSDIdentityConstraintDefinitionItemProvider
   {
     XSDIdentityConstraintDefinition xsdIdentityConstraintDefinition = ((XSDIdentityConstraintDefinition)object);
     return 
-      XSDEditPlugin.getImage
+      XSDEditPlugin.INSTANCE.getImage
         (XSDIdentityConstraintCategory.KEY_LITERAL ==  xsdIdentityConstraintDefinition.getIdentityConstraintCategory() ?  
           "full/obj16/XSDIdentityConstraintDefinitionKey" :
           XSDIdentityConstraintCategory.KEYREF_LITERAL == xsdIdentityConstraintDefinition.getIdentityConstraintCategory() ?  
