@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XSDMaxExclusiveFacetItemProvider.java,v 1.3 2005/06/12 12:34:45 emerks Exp $
+ * $Id: XSDMaxExclusiveFacetItemProvider.java,v 1.4 2006/01/25 00:27:41 emerks Exp $
  */
 package org.eclipse.xsd.provider;
 
@@ -63,8 +63,8 @@ public class XSDMaxExclusiveFacetItemProvider
       itemPropertyDescriptors.add
         (new ItemPropertyDescriptor
           (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
-           XSDEditPlugin.getString("_UI_Value_label"),
-           XSDEditPlugin.getString("_UI_ValueMaxExclusiveFacet_description"),
+           XSDEditPlugin.INSTANCE.getString("_UI_Value_label"),
+           XSDEditPlugin.INSTANCE.getString("_UI_ValueMaxExclusiveFacet_description"),
            xsdPackage.getXSDMaxFacet_Value(),
            true,
            ItemPropertyDescriptor.TEXT_VALUE_IMAGE));
@@ -78,6 +78,6 @@ public class XSDMaxExclusiveFacetItemProvider
    */
   public Object getImage(Object object)
   {
-    return XSDEditPlugin.getImage("full/obj16/XSDMaxExclusiveFacet");
+    return XSDEditPlugin.INSTANCE.getImage("full/obj16/XSDMaxExclusiveFacet");
   }
 }
