@@ -1,7 +1,7 @@
 /**
  * <copyright>
  *
- * Copyright (c) 2002-2004 IBM Corporation and others.
+ * Copyright (c) 2002-2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
  *
  * </copyright>
  *
- * $Id: XSDRedefineItemProvider.java,v 1.4 2005/06/12 12:34:45 emerks Exp $
+ * $Id: XSDRedefineItemProvider.java,v 1.5 2006/01/25 00:27:41 emerks Exp $
  */
 package org.eclipse.xsd.provider;
 
@@ -83,7 +83,7 @@ public class XSDRedefineItemProvider
    */
   public Object getImage(Object object)
   {
-    return XSDEditPlugin.getImage("full/obj16/XSDRedefine");
+    return XSDEditPlugin.INSTANCE.getImage("full/obj16/XSDRedefine");
   }
 
   public String getText(Object object)
